.DraftAction__button{display:inline-flex;width:28px;height:28px;align-items:center;justify-content:center;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.4);fill:rgba(var(--center-channel-color-rgb), 0.4)}.DraftAction__button:hover,.DraftAction__button:active,.DraftAction__button--active{background:rgba(var(--center-channel-color-rgb), 0.08)}.DraftAction__button span{display:flex}.DraftAction .DraftAction__button--delete:hover,.DraftAction .DraftAction__button--delete:active,.DraftAction .DraftAction__button--delete--active{background:rgba(var(--dnd-indicator-rgb), 0.08)}.DraftAction .icon{color:rgba(var(--center-channel-color-rgb), 0.64);fill:rgba(var(--center-channel-color-rgb), 0.64)}.DraftAction .icon:hover{color:rgba(var(--center-channel-color-rgb), 0.8);fill:rgba(var(--center-channel-color-rgb), 0.8)}.DraftAction .icon-trash-can-outline,.DraftAction .icon-trash-can-outline:hover{color:var(--dnd-indicator);fill:var(--dnd-indicator)}.DraftAction+.DraftAction{padding-left:5px}
.ScheduledPostActions{display:inline-flex}
.post--editing__wrapper{position:relative}.post--editing__wrapper textarea,.post--editing__wrapper #edit_textbox_placeholder{padding:13px 16px 12px 16px;padding-right:50px}.post--editing__wrapper .edit-post-footer.has-error{color:rgb(var(--dnd-indicator-rgb))}
.DraftTitle__avatar{margin:0 .5em}.DraftTitle__group-icon{width:18px;min-width:18px;height:18px;border-radius:2px;margin:0 5px;background:rgba(var(--center-channel-color-rgb), 0.16);font-size:12px;font-weight:600;line-height:18px;text-align:center}
.Panel{border:1px solid rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px;background-color:var(--center-channel-bg);box-shadow:var(--elevation-1);cursor:pointer;transition:box-shadow .3s ease-in-out}.Panel+.Panel{margin-top:16px}.Panel:hover{border-color:rgba(var(--center-channel-color-rgb), 0.16);box-shadow:var(--elevation-2);transition-duration:.15s}.Panel:hover .PanelHeader__actions,.Panel:focus-within .PanelHeader__actions{opacity:1}.Panel:hover .PanelHeader__info,.Panel:focus-within .PanelHeader__info{display:none}.Panel.draftError{border-color:var(--error-text)}
.DraftPanelBody{display:flex;padding:16px}.DraftPanelBody__right{flex:1}.DraftPanelBody__right .priorityLabelsContainer{padding:0 0 0 8px}.DraftPanelBody__right .BurnOnReadLabel{padding-top:0;padding-left:6px}.DraftPanelBody.post:hover{background-color:var(--center-channel-bg)}.DraftPanelBody .file-preview__container{height:auto;flex-wrap:wrap;padding-top:3px;margin:0 -5px}.DraftPanelBody .file-preview__container .file-preview.post-image__column{margin:1px 5px 5px;cursor:pointer}
.ScheduledPostList{width:100%;height:100%}.ScheduledPostList.nonVirtualizedScheduledPostList{position:absolute;overflow-y:auto}.ScheduledPostList .nonVirtualizedScheduledPostRow{margin:0 24px 16px 24px}.ScheduledPostList .nonVirtualizedScheduledPostRow.firstRow{margin-top:24px}.ScheduledPostList .scheduledPostListErrorIndicator{display:flex;flex-direction:row;align-items:center;margin:24px 24px 16px 24px;font-weight:bold;padding-block:10px}.ScheduledPostList .AlertBanner__body{color:rgba(var(--center-channel-color-rgb), 0.75)}@keyframes borderColorAnimation{0%{background:rgba(var(--mention-highlight-bg-rgb), 0.5)}100%{background:initial}}.ScheduledPostList .Panel.highlighted{animation:borderColorAnimation 10s}
.tabs{display:flex;width:100%;flex-direction:column;margin:0}.tabs .nav-tabs{border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08);margin:0;padding-inline:12px}.tabs .nav-tabs li{margin-right:0}.tabs .nav-tabs li a{padding:13px 10px;border:none;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.75);font-size:14px;font-weight:600;line-height:20px;transition:all .15s ease}.tabs .nav-tabs li a:hover,.tabs .nav-tabs li a:active,.tabs .nav-tabs li a:focus,.tabs .nav-tabs li a:focus-within{border:none;border-radius:none;background:rgba(0,0,0,0);color:var(--center-channel-color)}.tabs .nav-tabs li.active{border-bottom:2px solid var(--button-bg)}.tabs .nav-tabs li.active a{color:var(--button-bg)}.tabs .nav-tabs li:not(:first-child){margin-left:8px}
.Drafts{display:grid;background:rgba(var(--center-channel-color-rgb), 0.04);grid-template-areas:"header" "list";grid-template-columns:var(--list);grid-template-rows:56px 1fr}.Drafts__header{border-bottom:var(--border-default);grid-area:header}.Drafts .channel-header__icon,.Drafts .search__form{margin-top:1px}.Drafts__main{position:absolute;top:56px;display:flex;overflow:auto;width:100%;height:calc(100% - 56px);flex-flow:column nowrap}.Drafts .no-results__wrapper>svg{margin-bottom:20px}.Drafts #draft_tabs{grid-area:list}.Drafts #draft_tabs .nav.nav-tabs .drafts_tab .badge{position:relative;top:-2px;display:inline-block;height:14px;margin-left:6px;background:rgba(var(--center-channel-color-rgb), 0.2);color:rgba(var(--center-channel-color-rgb), 0.75);font-size:11px}.Drafts #draft_tabs .nav.nav-tabs .drafts_tab.active .badge{background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.Drafts #draft_tabs .tab-content{height:100%}.Drafts #draft_tabs .tab-content div[role=tabpanel]{position:relative;height:100%}.Drafts #draft_tabs .tab-content .DraftList.Drafts__main{top:0;height:100%}.Drafts span.MuiBadge-badge{position:relative;top:-2px}.Drafts .virtualizedVariableListRowWrapper{padding:0 24px 16px 24px}.Drafts .virtualizedVariableListRowWrapper.firstRow{padding-top:24px}@media screen and (max-width: 768px){.Drafts{grid-template-rows:0 1fr}.Drafts>.Header{display:none}.Drafts .Header{border-top:var(--border-default)}}.Drafts .Panel .post--editing__wrapper{margin:16px}

/*# sourceMappingURL=2794.87a23c50f78eb348575e.css.map*/