.productNotices{width:692px}.productNotices .GenericModal__body{padding:0}.productNotices .modal-title{font-size:22px;line-height:28px}.productNotices .modal-header{min-height:auto;padding-top:48px;padding-bottom:0px}.productNotices .productNotices__helpText{opacity:.75}.productNotices .productNotices__img{display:block;max-height:347px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;margin:32px auto 0}.productNotices .productNotices__imageDiv{margin:0 auto}.productNotices .productNotices__info{position:fixed;z-index:1;bottom:45px}.productNotices .circle{width:6px;height:6px;margin:0 3px;background-color:var(--center-channel-color);vertical-align:middle}.productNotices svg{margin-right:5px;margin-left:23px;vertical-align:middle}

/*# sourceMappingURL=452.e507747b2f3bb16105f2.css.map*/