"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[8360],{28360:(e,t,a)=>{a.r(t),a.d(t,{default:()=>c}),a(15724);var l=a(36418),o=a.n(l),s=a(14778),r=a(37270),n=a(26614),i=a(17518);const c=e=>{const t=(0,s.useIntl)(),{formatMessage:a}=t,c=(0,r.useSelector)(n.zj);if((0,l.useEffect)((()=>{document.body.classList.add("sticky");const e=document.getElementById("root");return e&&e.classList.add("container-fluid"),()=>{document.body.classList.remove("sticky");const e=document.getElementById("root");e&&e.classList.remove("container-fluid")}}),[]),!c)return null;const m=[];return c.AboutLink&&m.push(o().createElement(i.A,{key:"about_link",id:"about_link",className:"footer-link",location:"header_footer_template",href:c.AboutLink},a({id:"web.footer.about",defaultMessage:"About"}))),c.PrivacyPolicyLink&&m.push(o().createElement(i.A,{key:"privacy_link",id:"privacy_link",className:"footer-link",location:"header_footer_template",href:c.PrivacyPolicyLink},a({id:"web.footer.privacy",defaultMessage:"Privacy Policy"}))),c.TermsOfServiceLink&&m.push(o().createElement(i.A,{key:"terms_link",id:"terms_link",className:"footer-link",location:"header_footer_template",href:c.TermsOfServiceLink},a({id:"web.footer.terms",defaultMessage:"Terms"}))),c.HelpLink&&m.push(o().createElement(i.A,{key:"help_link",id:"help_link",className:"footer-link",location:"header_footer_template",href:c.HelpLink},a({id:"web.footer.help",defaultMessage:"Help"}))),o().createElement("div",{className:"inner-wrap"},o().createElement("div",{className:"row content"},e.children),o().createElement("div",{className:"row footer"},o().createElement("div",{id:"footer_section",className:"footer-pane col-xs-12"},o().createElement("div",{className:"col-xs-12"},o().createElement("span",{id:"company_name",className:"pull-right footer-site-name"},"Mattermost")),o().createElement("div",{className:"col-xs-12"},o().createElement("span",{id:"copyright",className:"pull-right footer-link copyright"},`© 2015-${(new Date).getFullYear()} Mattermost, Inc.`),o().createElement("span",{className:"pull-right"},m)))))}}}]);
//# sourceMappingURL=8360.6024746d38faeadee3d2.js.map