.ShowTranslationModal{min-width:960px}.ShowTranslationModal__content{display:flex;flex-direction:row;padding-bottom:32px;gap:16px}.ShowTranslationModal__messageBlock{flex:1;padding:16px;border-radius:4px;background-color:var(--center-channel-bg)}.ShowTranslationModal__messageBlock--original{background-color:rgba(var(--center-channel-color-rgb), 0.04)}.ShowTranslationModal__badgeContainer{display:flex;flex-direction:row;align-items:center;margin-bottom:12px;gap:8px}.ShowTranslationModal__languageText{color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;font-weight:600;text-transform:uppercase}@media screen and (max-width: 1000px){.ShowTranslationModal{width:calc(100vw - 40px);min-width:unset;max-width:calc(100vw - 40px)}}@media screen and (max-width: 768px){.ShowTranslationModal{width:calc(100vw - 32px);max-width:calc(100vw - 32px)}.ShowTranslationModal__content{flex-direction:column}}@media screen and (max-width: 640px){.ShowTranslationModal{width:100vw;max-width:100vw}}

/*# sourceMappingURL=7672.5752104be11399890cae.css.map*/