#searchInput{flex:none}.backstage-footer{display:flex;height:auto;flex-direction:row;padding:8px;border:1px solid rgba(0,0,0,.15);border-top:none;background:#fff;color:rgba(0,0,0,.5);font-size:1.1em;text-align:right}.backstage-footer .backstage-footer__cell{width:100%;text-align:right}

/*# sourceMappingURL=6347.0ef923a27fc898098ff8.css.map*/