"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[1380],{81380:(e,t,a)=>{a.r(t),a.d(t,{default:()=>u});var r=a(36418),i=a.n(r),s=a(14778),d=a(46946),m=a(22583),n=a(36397),o=a(90327);const u=function(e){let{userId:t,timezone:a,onExited:u,postId:l,actions:c}=e;const{formatMessage:_}=(0,s.useIntl)(),p=_({id:"post_reminder_custom_time_picker_modal.defaultMsg",defaultMessage:"Set a reminder"}),f=_({id:"post_reminder.custom_time_picker_modal.header",defaultMessage:"Set a reminder"}),b=_({id:"post_reminder.custom_time_picker_modal.submit_button",defaultMessage:"Set reminder"}),k=(0,o.Yt)(a),h=(0,m.hq)(k),g=(0,r.useCallback)((e=>{c.addPostReminder(t,l,(0,n.Id)(e.toDate())),u()}),[c,l,t,u]);return i().createElement(d.A,{onExited:u,ariaLabel:p,header:f,initialTime:h,onConfirm:g,confirmButtonText:b,relativeDate:!0})}}}]);
//# sourceMappingURL=1380.4c1fe8900b6540a3ac0f.js.map