@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.app-bar{position:relative;display:flex;min-height:0;flex-flow:column}@media(max-width: 768px){.app-bar{display:none}}.app-bar__top{position:relative;display:flex;width:44px;flex:1;flex-flow:column;padding-top:15px;-ms-overflow-style:none;overflow-x:hidden;overflow-y:scroll;scrollbar-width:none;text-align:center}.app-bar__top .app-bar__icon{position:relative;z-index:21;width:100%;border-left:none;margin-bottom:16px;cursor:pointer}.app-bar__top .app-bar__icon--active::before{position:absolute;top:0;left:0;width:3px;height:24px;border-radius:0 var(--radius-xs) var(--radius-xs) 0;background-color:var(--sidebar-text-active-border);content:""}.app-bar__top .app-bar__icon--active .app-bar__icon-inner,.app-bar__top .app-bar__icon--active span:not(.pulsating_dot){box-shadow:0 0 0 2px var(--sidebar-text-active-border)}.app-bar__top .app-bar__icon--active .app-bar__icon-inner:hover,.app-bar__top .app-bar__icon--active span:not(.pulsating_dot):hover{box-shadow:0 0 0 2px rgba(var(--sidebar-text-active-border-rgb), 0.92) !important}.app-bar__top .app-bar__icon .app-bar__icon-inner,.app-bar__top .app-bar__icon span:not(.pulsating_dot){display:block;overflow:hidden;width:24px;height:24px;border-radius:var(--radius-full);margin:0 auto;line-height:1}.app-bar__top .app-bar__icon .app-bar__icon-inner:hover,.app-bar__top .app-bar__icon span:not(.pulsating_dot):hover{box-shadow:0 0 0 2px rgba(var(--sidebar-text-rgb), 0.16)}.app-bar__top .app-bar__icon .app-bar__icon-inner img,.app-bar__top .app-bar__icon span:not(.pulsating_dot) img{width:24px;height:24px;border-radius:var(--radius-full)}.app-bar__top .app-bar__icon span:not(.pulsating_dot){padding:2px;background-color:#fff;fill:var(--button-bg);font-size:14px;line-height:20px;vertical-align:middle}.app-bar__top .app-bar__icon span:not(.pulsating_dot).CompassIcon,.app-bar__top .app-bar__icon span:not(.pulsating_dot).icon-brand-zoom{font-size:20px}.app-bar__top .app-bar__icon span:not(.pulsating_dot).CompassIcon::before,.app-bar__top .app-bar__icon span:not(.pulsating_dot).icon-brand-zoom::before{margin:0 0 0 .5px}.app-bar__top .app-bar__icon .app-bar__old-icon{color:rgba(var(--sidebar-text-rgb), 0.64)}.app-bar__top .app-bar__icon .app-bar__old-icon:hover,.app-bar__top .app-bar__icon .app-bar__old-icon--active{color:rgba(var(--sidebar-text-rgb), 0.8)}.app-bar__top .app-bar__icon .app-bar__icon-inner--centered{display:grid;place-items:center}.app-bar__top .app-bar__divider{width:28px;border-top:1px solid rgba(var(--sidebar-text-rgb), 0.16);margin-top:0;margin-bottom:19px}.app-bar__top .app-bar__icon.channel-header__icon--active{background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);fill:var(--button-bg)}.app-bar__bottom{position:relative;display:flex;flex-flow:column;align-items:center;padding-top:24px;padding-bottom:36px}.app-bar__bottom .app_bar__marketplace_button{display:flex;align-items:center;justify-content:center;border:0;border-radius:4px;background:none;color:rgba(var(--center-channel-color-rgb), 0.64);width:28px;height:28px;padding:6px;font-size:16px;color:rgba(var(--sidebar-text-rgb), 0.64)}.app-bar__bottom .app_bar__marketplace_button:focus,.app-bar__bottom .app_bar__marketplace_button:focus-within{box-sizing:border-box;border:2px solid rgba(var(--button-bg-rgb), 0.32);box-shadow:none;outline:none}.app-bar__bottom .app_bar__marketplace_button:hover{border:0;background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.8)}.app-bar__bottom .app_bar__marketplace_button:active{border:0;background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.app-bar__bottom .app_bar__marketplace_button:disabled{background:none;color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.app-bar__bottom .app_bar__marketplace_button:hover{background-color:rgba(var(--sidebar-text-rgb), 0.08);color:rgba(var(--sidebar-text-rgb), 0.72)}.app-bar__top::-webkit-scrollbar{display:none}

/*# sourceMappingURL=1748.f59f7b91e943c328180c.css.map*/