"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[4526],{34526:(e,a,t)=>{t.r(a),t.d(a,{default:()=>C}),t(43617),t(93991);var n=t(36418),l=t.n(n),s=t(14778),r=t(37270),d=t(30413),i=t(9916),u=t(70669),c=t(19174),m=t(51877),o=t(77813),p=t(66039),h=t(69440);function C(e){let{setChannelRef:a}=e;const t=(0,s.useIntl)(),C=(0,r.useSelector)(i.OM),g=(0,r.useDispatch)(),b=(0,n.useCallback)((()=>{C.length&&g((0,d.Zi)(C.map((e=>e.id))))}),[C,g]);return 0===C.length?null:l().createElement("div",{className:"SidebarChannelGroup dropDisabled a11y__section"},l().createElement(p.U,{displayName:t.formatMessage({id:"sidebar.types.unreadChannels.displayName",defaultMessage:"UNREADS"})},l().createElement(o.A,{id:"unreads",name:t.formatMessage({id:"sidebar.types.unreadChannels.ariaLabel",defaultMessage:"Unread"})},l().createElement(m.A,{id:"unreads",handleViewCategory:b,numChannels:C.length}),l().createElement(u.wv,null),l().createElement(c.A,{id:"unreads"}))),l().createElement("div",{className:"SidebarChannelGroup_content"},l().createElement("ul",{role:"list",className:"NavGroupContent"},C.map(((e,t)=>l().createElement(h.A,{key:e.id,channelIndex:t,channelId:e.id,setChannelRef:a,isCategoryCollapsed:!1,isCategoryDragged:!1,isDraggable:!1,isAutoSortedCategory:!0}))))))}}}]);
//# sourceMappingURL=4526.b225700cbed40df1cb5c.js.map