#SidebarContainer .SidebarGlobalThreads .SidebarChannel{height:100%}#SidebarContainer .SidebarGlobalThreads .SidebarLink{width:100%}#SidebarContainer .SidebarGlobalThreads .SidebarLink .icon{padding:3px;margin-right:7px;margin-left:-1px}#SidebarContainer .SidebarGlobalThreads .SidebarLink .icon svg{fill:rgba(var(--sidebar-text-rgb), 0.64);vertical-align:middle}#SidebarContainer .SidebarGlobalThreads .SidebarLink.unread-title svg{fill:var(--sidebar-text)}#SidebarContainer .SidebarGlobalThreads .SidebarLink:hover{padding-right:16px}#SidebarContainer .SidebarGlobalThreads .SidebarLink:hover .badge{position:initial;visibility:visible}.sidebar--left .SidebarGlobalThreads{padding-bottom:0;margin-top:13px}.sidebar--left .SidebarGlobalThreads .icon{width:auto;padding-left:1px;margin-top:1px}.sidebar--left .SidebarGlobalThreads .icon svg{fill:rgba(var(--sidebar-text-rgb), 0.75)}.sidebar--left .SidebarGlobalThreads .SidebarChannelLinkLabel_wrapper{display:flex;flex:1}.sidebar--left .SidebarGlobalThreads .badge{margin:0 12px 0 0}

/*# sourceMappingURL=1428.6ff5cd2bd6cc56cc05a3.css.map*/