.content-layout-column{display:flex;max-width:540px;flex-flow:column;justify-content:center;border:none;box-shadow:none}.content-layout-column .content-layout-column-svg{align-self:center}.content-layout-column .content-layout-column-title{color:var(--title-color-indigo-500);font-family:Metropolis;font-size:40px;font-weight:600;letter-spacing:-0.02em;line-height:48px;text-align:center}.content-layout-column .content-layout-column-message{color:rgba(var(--center-channel-color-rgb), 0.75);font-size:16px;font-weight:400;line-height:24px;text-align:center}.content-layout-column .content-layout-column-extra-content{display:flex;flex:1;margin-top:30px}@media screen and (max-width: 699px){.content-layout-column{width:100%;padding:0 40px}}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.login-mfa-form{display:flex;flex:1}.login-mfa-form .login-mfa-form-input{flex:1;background-color:var(--center-channel-bg)}.login-mfa-form .login-mfa-form-button-container{display:flex;width:170px;margin-left:8px;background-color:var(--center-channel-bg)}.login-mfa-form .login-mfa-form-button-container .login-mfa-form-button-submit{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;border-radius:4px;background:var(--button-bg);color:var(--button-color);font-weight:600;transition:all .15s ease-out;height:48px;padding:0 24px;font-size:16px;line-height:18px;flex:1;margin:0}.login-mfa-form .login-mfa-form-button-container .login-mfa-form-button-submit:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.login-mfa-form .login-mfa-form-button-container .login-mfa-form-button-submit:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.login-mfa-form .login-mfa-form-button-container .login-mfa-form-button-submit:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.login-mfa-form .login-mfa-form-button-container .login-mfa-form-button-submit:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.login-mfa-form .login-mfa-form-button-container .login-mfa-form-button-submit i{display:flex;font-size:18px}

/*# sourceMappingURL=5677.f65415f3f4c59db170f6.css.map*/