.SidebarRecaps{margin-bottom:12px}.SidebarRecaps .SidebarChannel{height:32px;padding:0}.SidebarRecaps .SidebarChannel.active{background-color:rgba(var(--sidebar-text-rgb), 0.08)}.SidebarRecaps .SidebarChannel.active .SidebarLink::before{position:absolute;top:0;left:0;width:2px;height:100%;border-radius:0 var(--radius-s) var(--radius-s) 0;background-color:var(--sidebar-text-active-border);content:""}.SidebarRecaps .SidebarChannel:hover:not(.active){background-color:rgba(var(--sidebar-text-rgb), 0.04)}.SidebarRecaps .SidebarLink{position:relative;display:flex;height:100%;align-items:center;padding:0 16px 0 18px;color:rgba(var(--sidebar-text-rgb), 0.72);text-decoration:none}.SidebarRecaps .SidebarLink .icon{display:flex;align-items:center;padding:3px;margin-right:1px;color:rgba(var(--sidebar-text-rgb), 0.64);font-size:18px;opacity:.64}.SidebarRecaps .SidebarLink .icon svg{vertical-align:middle}.SidebarRecaps .SidebarLink .SidebarChannelLinkLabel_wrapper{min-width:0;flex:1;padding:2px 4px}.SidebarRecaps .SidebarLink .SidebarChannelLinkLabel{overflow:hidden;font-size:14px;line-height:20px;text-overflow:ellipsis;white-space:nowrap}.SidebarRecaps .active .SidebarLink{color:var(--sidebar-text)}.SidebarRecaps .active .SidebarLink .icon{color:var(--sidebar-text)}.SidebarRecaps .active .SidebarLink .SidebarChannelLinkLabel{font-weight:400}

/*# sourceMappingURL=745.c215c575a3184cb005fc.css.map*/