.mm-modal-generic-section-item{display:flex;flex-direction:column;gap:8px}.mm-modal-generic-section-item__title{display:flex;align-items:center;padding:0;margin:0 0 8px;color:var(--center-channel-color);font-family:"Open Sans",sans-serif;font-size:14px;font-style:normal;font-weight:600;line-height:20px}.mm-modal-generic-section-item__description{display:flex;align-items:center;padding:0;margin:0;color:rgba(var(--center-channel-color-rgb), 0.64);font-family:"Open Sans",sans-serif;font-size:12px;font-style:normal;font-weight:400;line-height:16px}.mm-modal-generic-section-item__error{display:flex;align-items:center;padding:0;margin:12px 0 0 0;color:var(--error-text);font-family:"Open Sans",sans-serif;font-size:12px;font-style:normal;font-weight:400;line-height:16px}.mm-modal-generic-section-item__error svg{flex-shrink:0;margin-right:6px}.mm-modal-generic-section-item__content{display:flex;flex-direction:column}.mm-modal-generic-section-item__content.inline{flex-direction:row;gap:24px}.mm-modal-generic-section-item__fieldset-checkbox-ctr{display:flex;flex-direction:row;align-items:center;margin-bottom:5px;gap:8px}.mm-modal-generic-section-item__fieldset-checkbox{display:flex;flex-direction:row;align-items:center;margin-bottom:0;cursor:pointer;font-size:14px;gap:8px;line-height:20px}.mm-modal-generic-section-item__fieldset-checkbox span{font-weight:400}.mm-modal-generic-section-item__fieldset-radio{display:flex;flex-direction:column;gap:12px}.mm-modal-generic-section-item__label-radio{display:flex;width:fit-content;flex-direction:row;align-items:center;margin-bottom:0;cursor:pointer;font-size:14px;font-weight:400;gap:8px;line-height:20px}.mm-modal-generic-section-item__fieldset-react-select{max-width:240px;flex-grow:1}.mm-modal-generic-section-item__input-checkbox{width:1.6rem;height:1.6rem}.mm-modal-generic-section-item input[type=checkbox]{display:grid;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);border-radius:3px;margin:0;-webkit-appearance:none;appearance:none;background-color:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.24);cursor:pointer;font:inherit;place-content:center;-webkit-transition:background-color 200ms ease-out;-moz-transition:background-color 200ms ease-out;-o-transition:background-color 200ms ease-out;transition:background-color 200ms ease-out}.mm-modal-generic-section-item input[type=checkbox]::before{width:10px;height:10px;background:var(--button-color);clip-path:polygon(0% 57%, 32% 88%, 100% 20%, 88% 8%, 32% 64%, 12% 45%);content:"";transform:scale(0);transform-origin:center center;transition:200ms transform ease-in-out}.mm-modal-generic-section-item input[type=checkbox]:checked::before{transform:scale(1)}.mm-modal-generic-section-item input[type=checkbox]:checked{border-color:var(--button-bg);background:var(--button-bg)}.mm-modal-generic-section-item input[type=radio]{display:grid;width:1.6rem;height:1.6rem;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);border-radius:50%;margin:0;-webkit-appearance:none;appearance:none;background-color:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.24);cursor:pointer;font:inherit;place-content:center}.mm-modal-generic-section-item input[type=radio]::before{width:8px;height:8px;border-radius:50%;background:var(--button-bg);content:"";transform:scale(0);transform-origin:center center;transition:200ms transform ease-in-out}.mm-modal-generic-section-item input[type=radio]:checked::before{transform:scale(1)}.mm-modal-generic-section-item input[type=radio]:checked{border-color:var(--button-bg)}
.mm-modal-header{display:flex;align-items:center;padding:20px 20px 20px 32px;border-bottom:var(--border-light);background:none;gap:8px}.mm-modal-header__title{padding:0;margin:0;color:var(--center-channel-color);font-family:"Metropolis",serif;font-size:22px;font-style:normal;font-weight:600;line-height:28px;white-space:nowrap}.mm-modal-header__vertical-divider{display:inline-block;width:1px;height:24px;margin:0 8px;background:rgba(var(--center-channel-color-rgb), 0.16);vertical-align:middle}.mm-modal-header__subtitle{overflow:hidden;padding:0;margin:0;color:rgba(var(--center-channel-color-rgb), 0.56);font-family:inherit;font-size:12px;font-style:normal;font-weight:400;line-height:20px;text-overflow:ellipsis;vertical-align:middle;white-space:nowrap}.mm-modal-header__ctr{display:flex;flex:1 1 auto;align-items:center;justify-content:flex-end}@media screen and (max-width: 768px){.mm-modal-header{padding:18px 24px}.mm-modal-header__title{font-size:20px}.mm-modal-header__subtitle{display:none}.mm-modal-header__vertical-divider{display:none}}
.mm-modal-generic-section{display:flex;flex-direction:column}.mm-modal-generic-section .modalSectionHeader{display:flex;flex-direction:column;gap:8px;margin-block-end:24px}.mm-modal-generic-section .modalSectionHeader .modalSectionTitle{display:flex;align-items:center;padding:0;margin:0;color:var(--center-channel-color);font-family:"Metropolis",sans-serif;font-size:16px;font-style:normal;font-weight:600;gap:8px;line-height:24px}.mm-modal-generic-section .modalSectionHeader .modalSectionDescription{display:flex;align-items:center;padding:0;margin:0;color:rgba(var(--center-channel-color-rgb), 0.64);font-family:"Open Sans",sans-serif;font-size:12px;font-style:normal;font-weight:400;line-height:16px}.mm-modal-generic-section .modalSectionContent{display:flex;flex-direction:column;gap:24px}
.modal .ChannelNotificationModal{width:100%;max-width:600px;margin-top:5vh !important;overflow-y:hidden}.modal .ChannelNotificationModal .modal-content{flex-direction:column;border:var(--border-default);border-radius:var(--radius-l);box-shadow:var(--elevation-6);overflow-y:hidden}.modal .ChannelNotificationModal .modal-content .GenericModal__wrapper{display:flex;overflow:hidden;max-height:calc(100vh - 160px);flex-direction:column;border:var(--border-default);border-radius:var(--radius-l);box-shadow:var(--elevation-6)}.modal .ChannelNotificationModal .modal-content .GenericModal__wrapper .modal-header{padding:0 !important}.modal .ChannelNotificationModal .modal-content .GenericModal__wrapper .modal-body{display:flex;width:100%;max-width:1024px;min-height:150px;flex-direction:column;gap:24px;overflow-x:hidden;overflow-y:auto}.modal .ChannelNotificationModal .modal-content .GenericModal__wrapper .modal-body main{display:flex;width:100%;max-width:1024px;min-height:150px;flex-direction:column;padding:28px 32px;gap:24px;overflow-x:hidden;overflow-y:auto}.modal .ChannelNotificationModal .modal-content .GenericModal__wrapper .modal-footer{display:flex;width:100%;max-width:1024px;align-items:center;justify-content:flex-end;gap:8px}.modal .ChannelNotificationModal__ctr{display:flex;place-items:center}.modal .ChannelNotificationModal__reset-btn{display:flex;align-items:center;padding:5px 8px;border:none;border-radius:4px;background:rgba(0,0,0,0);color:var(--button-bg);font-size:12px;font-weight:600;gap:4px}.modal .ChannelNotificationModal__reset-btn i{font-size:16px}.modal .ChannelNotificationModal__reset-btn:hover,.modal .ChannelNotificationModal__reset-btn:active{background:rgba(var(--button-bg-rgb), 0.08)}.modal .ChannelNotificationModal__server-error{flex-grow:1;color:var(--error-text)}.modal .ChannelNotificationModal__divider{border-bottom:var(--border-light)}@media screen and (max-width: 768px){.modal .ChannelNotificationModal{max-width:100%;margin:0}.modal .ChannelNotificationModal .modal-content{display:flex;max-height:100vh;flex-direction:column;border-radius:unset}}@media screen and (max-height: 900px)and (min-width: 768px){.modal .ChannelNotificationModal .modal-content{max-height:calc(100vh - 160px)}}@media screen and (max-height: 600px)and (min-width: 768px){.modal .ChannelNotificationModal .modal-content,.modal .ChannelNotificationModal .GenericModal__wrapper{max-height:85vh !important}}@media screen and (max-width: 640px){.modal .ChannelNotificationModal .GenericModal__wrapper{max-height:unset !important}}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.url-input-main{display:flex;flex-direction:column}.url-input-main .url-input-container{display:flex;min-height:32px;flex-wrap:wrap;align-items:center;margin-top:4px}.url-input-main .url-input-container .url-input-label{max-width:100%;flex:none;margin-right:4px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:17px;overflow-wrap:anywhere}.url-input-main .url-input-container .url-input-editable-container{width:auto;margin-right:6px}.url-input-main .url-input-container .url-input-editable-container .url-input-editable-wrapper{padding:0 12px}.url-input-main .url-input-container .url-input-editable-container .url-input-editable-wrapper .url-input-editable-path{height:26px;border:0;border-radius:0;font-size:12px;line-height:16px}.url-input-main .url-input-container .url-input-button{border:none;box-shadow:none;color:var(--link-color);font-size:12px;font-weight:600;line-height:16px;padding:0;border:none;background:var(--center-channel-bg);box-shadow:none}.url-input-main .url-input-container .url-input-button:hover,.url-input-main .url-input-container .url-input-button:active,.url-input-main .url-input-container .url-input-button:focus{text-decoration-line:underline}.url-input-main .url-input-container .url-input-button:disabled{color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed;text-decoration:none}.url-input-main .url-input-container .url-input-button .url-input-button-label{line-height:9px}.url-input-main .url-input-error{display:flex;margin-top:5px;color:var(--error-text);font-size:12px;line-height:16px;text-align:left}.url-input-main .url-input-error i{height:14px;align-self:baseline;margin-right:7px;font-size:14px}.url-input-main .url-input-error i::before{margin:0}
.channel-name-input-field{height:34px !important;border:0 !important;border-radius:0 !important}
.ManagedCategorySelector.Input_container{margin-top:24px}.ManagedCategorySelector .Input_wrapper{padding:0 1px}.ManagedCategorySelector .Input{font-size:14px;line-height:20px}.ManagedCategorySelector .Input_legend{margin-left:8px}.ManagedCategorySelector__controlContainer .ManagedCategory__control{border:none;background-color:var(--center-channel-bg);box-shadow:none}.ManagedCategorySelector__controlContainer .ManagedCategory__control .ManagedCategory__input{box-shadow:none;color:var(--center-channel-color)}.ManagedCategorySelector__controlContainer .ManagedCategory__control .ManagedCategory__input-container{color:var(--center-channel-color)}.ManagedCategory__menu{background-color:var(--center-channel-bg) !important}.ManagedCategorySelector__createLabelPrefix{opacity:.75}.ManagedCategory__indicator-separator{display:none}.ManagedCategorySelector__valueContainerInner{display:flex;overflow:hidden;flex:1;align-items:center;gap:6px}.ManagedCategorySelector__folderIcon{flex-shrink:0;color:rgba(var(--center-channel-color-rgb), 0.64)}.ManagedCategory__placeholder,.ManagedCategory__single-value{position:absolute;left:22px}.ManagedCategory__single-value{color:var(--center-channel-color) !important}.ManagedCategorySelector__indicatorsContainer{margin-right:8px}.ManagedCategorySelector__indicatorsContainer i{color:rgba(var(--center-channel-color-rgb), 0.64);font-weight:normal}.ManagedCategorySelector__indicatorsContainer i::before{margin:0}.ManagedCategorySelector__option>div{z-index:999999;padding:8px 16px;cursor:pointer;line-height:20px}.ManagedCategorySelector__option.selected>div{background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--center-channel-color)}.ManagedCategorySelector__option.focused>div{background-color:rgba(var(--center-channel-color-rgb), 0.08)}.ManagedCategorySelector__option .ManagedCategory__option{display:flex;align-items:center;gap:12px}.ManagedCategorySelector__option svg{color:rgba(var(--center-channel-color-rgb), 0.64)}
.public-private-selector{display:flex;flex-direction:row}.public-private-selector .public-private-selector-button{display:flex;min-width:0;box-sizing:border-box;flex:1;align-items:center;padding:12px 22px 12px 12px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;background:var(--center-channel-bg)}.public-private-selector .public-private-selector-button:not(.a11y--focused){box-shadow:var(--elevation-1)}.public-private-selector .public-private-selector-button:not(:first-child){margin-left:8px}.public-private-selector .public-private-selector-button:not(.a11y--focused):hover{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);box-shadow:var(--elevation-2)}.public-private-selector .public-private-selector-button.selected{border:1px solid rgba(var(--sidebar-text-active-border-rgb), 0.32)}.public-private-selector .public-private-selector-button.selected .public-private-selector-button-icon,.public-private-selector .public-private-selector-button.selected .public-private-selector-button-icon-check{fill:var(--button-bg)}.public-private-selector .public-private-selector-button.selected:not(.a11y--focused):hover{border:1px solid rgba(var(--sidebar-text-active-border-rgb), 0.4);box-shadow:var(--elevation-2)}.public-private-selector .public-private-selector-button.disabled,.public-private-selector .public-private-selector-button.locked{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);cursor:not-allowed;opacity:.4}.public-private-selector .public-private-selector-button.disabled:hover,.public-private-selector .public-private-selector-button.locked:hover{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);box-shadow:var(--elevation-1)}.public-private-selector .public-private-selector-button.disabled.selected,.public-private-selector .public-private-selector-button.locked.selected{border:1px solid rgba(var(--sidebar-text-active-border-rgb), 0.32)}.public-private-selector .public-private-selector-button .public-private-selector-button-text{min-width:0;flex:1;margin-left:12px;text-align:left}.public-private-selector .public-private-selector-button .public-private-selector-button-text .public-private-selector-button-title{overflow:hidden;color:var(--center-channel-color);font-size:14px;font-weight:600;line-height:20px;text-overflow:ellipsis;white-space:nowrap}.public-private-selector .public-private-selector-button .public-private-selector-button-text .public-private-selector-button-title .public-private-selector-button-icon-upgrade{display:inline-flex;width:16px;height:16px;margin-left:8px;fill:var(--online-indicator);vertical-align:sub}.public-private-selector .public-private-selector-button .public-private-selector-button-text .public-private-selector-button-description{overflow:hidden;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:16px;text-overflow:ellipsis;white-space:nowrap}.public-private-selector .public-private-selector-button .public-private-selector-button-icon{display:flex;flex:none;fill:rgba(var(--center-channel-color-rgb), 0.75)}.public-private-selector .public-private-selector-button .public-private-selector-button-icon-check{display:flex;flex:none;margin-left:auto}@media screen and (max-width: 580px){.public-private-selector{flex-direction:column}.public-private-selector .public-private-selector-button:not(:first-child){margin:8px 0 0}}
.new-channel-modal .new-channel-modal-type-selector{margin-top:24px}.new-channel-modal .new-channel-modal-purpose-container{margin-top:28px}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea{width:100%;box-sizing:border-box;background:var(--center-channel-bg);color:var(--center-channel-color);font-size:14px;line-height:20px;resize:none}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea .Input_wrapper textarea.form-control{height:auto;border:none}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea:hover{border-color:rgba(var(--center-channel-color-rgb), 0.48)}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea:focus{border-color:var(--button-bg);box-shadow:inset 0 0 0 1px var(--button-bg)}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea.with-error{border-color:var(--error-text)}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-textarea.with-error:focus{box-shadow:inset 0 0 0 1px var(--error-text)}.new-channel-modal .new-channel-modal-purpose-container .new-channel-modal-purpose-info{margin-top:5px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:16px;text-align:left}@media screen and (max-width: 640px){.new-channel-modal .modal-content .GenericModal__wrapper{display:flex;height:100vh;flex-direction:column}.new-channel-modal .modal-content .GenericModal__wrapper>.modal-body{flex:1}}#new-channel-with-board-tooltip span{display:block;width:100%;text-align:left !important}#new-channel-with-board-tooltip .title{font-weight:800}#new-channel-with-board-tooltip .description{font-weight:500}@media screen and (max-width: 640px){.app__body.announcement-bar--fixed .new-channel-modal .modal-content .GenericModal__wrapper{height:calc(100vh - 40px)}}
.field-selector-menu-button{width:100%;height:40px;justify-content:start;border:none;font-weight:normal}.field-selector-menu-button:hover{background:rgba(var(--center-channel-color-rgb), 0.04)}.field-selector-menu-button:focus,.field-selector-menu-button[aria-expanded=true]{background:rgba(var(--button-bg-rgb), 0.08)}.field-selector-menu-button.disabled{cursor:not-allowed;opacity:.6}.field-selector-menu-button>span>span:first-child:not([style*="flex-wrap: wrap"]){overflow:hidden;padding-inline-start:10px;text-overflow:ellipsis;white-space:nowrap}.value-selector-menu-button__multi-values-container{display:flex;overflow:hidden;flex-grow:1;flex-wrap:wrap;gap:2px}.value-selector-menu-button__inner-wrapper{display:flex;width:100%;align-items:center;justify-content:space-between}.values-editor{width:100%}.values-editor .select__multi-value{display:flex;height:24px;align-items:center;border-radius:4px;margin:2px;background-color:rgba(var(--center-channel-color-rgb), 0.08)}.values-editor .select__multi-value__label{padding:0 4px 0 8px;font-size:12px}.values-editor .select__multi-value__remove{padding:0 4px;cursor:pointer}.values-editor .select__multi-value__remove:hover{background-color:rgba(var(--center-channel-color-rgb), 0.16)}.values-editor__simple-input{width:100%;height:40px;border:none;background:rgba(0,0,0,0);font-size:14px;padding-inline-start:22px}.values-editor__simple-input:focus{background:rgba(var(--center-channel-color-rgb), 0.06);outline:none}.values-editor__simple-input:disabled{cursor:not-allowed;opacity:.6}.values-editor .MenuItem__trailing-elements{display:flex;align-items:center;gap:4px}
.editor__test-btn{display:flex;align-items:center;justify-content:center;padding:10px 16px;border:1px solid var(--button-bg);border-radius:4px;background:rgba(0,0,0,0);color:var(--button-bg);cursor:pointer;font-weight:600}.editor__test-btn i{margin-right:8px}.editor__test-btn:hover{background-color:rgba(var(--button-bg-rgb), 0.08)}.editor__test-btn:disabled{border:1px solid rgba(var(--center-channel-color-rgb), 0.32);color:rgba(var(--center-channel-color-rgb), 0.56);cursor:not-allowed;opacity:.4}.editor__add-row-button{display:flex;align-items:center;padding:10px 16px;border:1px solid var(--button-bg);border-radius:4px;background-color:rgba(0,0,0,0);color:var(--button-bg);cursor:pointer;font-weight:600}.editor__add-row-button i{margin-right:8px;font-size:14px}.editor__add-row-button:hover{background-color:rgba(var(--button-bg-rgb), 0.08)}.editor__add-row-button:disabled{border:1px solid rgba(var(--center-channel-color-rgb), 0.32);color:rgba(var(--center-channel-color-rgb), 0.56);cursor:not-allowed;opacity:.4}.editor__help-text{color:var(--center-channel-color-72);font-size:12px}.editor__help-text p{margin-bottom:0}.editor__help-text a{display:inline-block;margin-top:8px;color:var(--link-color)}.editor__help-text a:hover{text-decoration:underline}
.cel-help-modal__content-container{display:flex;flex-direction:column}.cel-help-modal__content-container .cel-help-modal__content{padding:32px;padding-top:0}.cel-help-modal__content-container .cel-help-additional-info-modal__content{display:flex;flex-direction:column;padding:20px;background-color:rgba(var(--button-bg-rgb), 0.08)}.cel-help-modal__content-container .cel-help-additional-info-modal__content .cel-help-additional-info-modal__header{display:flex;align-items:center;margin-bottom:16px}.cel-help-modal__content-container .cel-help-additional-info-modal__content .cel-help-additional-info-modal__header i{margin-right:8px;color:var(--button-bg);font-size:24px}.cel-help-modal__content-container .cel-help-additional-info-modal__content .cel-help-additional-info-modal__header .cel-help-additional-info-modal__title{font-size:16px;font-weight:600}
.TestResultsModal{margin-top:5vh !important}.TestResultsModal .no-users-found{padding:32px 0;text-align:center}.TestResultsModal .GenericModal__body{padding:0 !important}.TestResultsModal .GenericModal__body .filter-row{padding:0 16px;margin:5px 0 10px}.TestResultsModal .GenericModal__body .filtered-user-list .filter-row span.member-count{margin-top:5px;opacity:.8}
.table-editor{margin-bottom:24px}.table-editor__table{width:100%;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;border-collapse:collapse}.table-editor th{padding:8px 12px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.16);background:rgba(var(--center-channel-color-rgb), 0.04);color:var(--center-channel-color-72);font-size:12px;font-weight:600;text-align:left}.table-editor td{border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08);vertical-align:middle}.table-editor .table-editor__column-header-value{padding-inline:10px}.table-editor th:nth-child(2),.table-editor td:nth-child(2){width:20%}.table-editor th:nth-child(3),.table-editor td:nth-child(3){width:50%}.table-editor th:nth-child(4),.table-editor td:nth-child(4){width:30px;text-align:right}.table-editor__blank-state{padding:16px;text-align:center}.table-editor__blank-state span{color:rgba(var(--center-channel-color-rgb), 0.64)}.table-editor__row-remove{border:none;background:none;color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer}.table-editor__row-remove:hover{color:var(--error-text)}.table-editor__actions-row{display:flex;justify-content:space-between;margin-top:12px}.table-editor__add-button-container{padding:8px}
.system-policy-indicator__title{margin-bottom:8px;font-weight:600;line-height:1.5}.system-policy-indicator__description{line-height:1.5}.system-policy-indicator__description strong{font-weight:600}.system-policy-indicator__more-link{padding:0;border:none;background:none;color:var(--link-color);cursor:pointer;font-family:inherit;font-size:inherit;font-weight:600;line-height:inherit;text-decoration:none}.system-policy-indicator__more-link:hover,.system-policy-indicator__more-link:focus{outline:none;text-decoration:underline}.system-policy-indicator__more-link:focus-visible{border-radius:2px;outline:2px solid var(--link-color);outline-offset:2px}.system-policy-indicator__policy-link{color:var(--link-color);font-weight:600;text-decoration:none}.system-policy-indicator__policy-link:hover{text-decoration:underline}.system-policy-indicator__policy-link:visited{color:var(--link-color)}.system-policy-indicator__policy-name{font-weight:600}.system-policy-indicator.compact .system-policy-indicator__main-message{margin-bottom:0}.system-policy-indicator.compact .system-policy-indicator__policy-list{display:none}
.SaveChangesPanel{position:fixed;z-index:1000;display:flex;width:63%;align-items:center;align-self:center;padding:12px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;animation-duration:300ms;animation-fill-mode:forwards;animation-name:entry-animation;animation-timing-function:ease;background:var(--center-channel-bg);box-shadow:var(--elevation-3);font-family:"Open Sans",sans-serif;transition:all 300ms ease}@keyframes entry-animation{from{bottom:0}to{bottom:20px}}@media screen and (max-width: 768px){.SaveChangesPanel{width:95%}}.SaveChangesPanel.error{border-color:var(--dnd-indicator);background:var(--dnd-indicator)}.SaveChangesPanel.saved{border-color:var(--online-indicator);background:var(--online-indicator)}.SaveChangesPanel__message{display:flex;align-items:center;margin:0;color:var(--center-channel-color);font-family:inherit;font-size:14px;font-style:normal;font-weight:600;line-height:20px}.SaveChangesPanel__message span{margin-left:8px}.SaveChangesPanel__message svg{margin-right:10px;color:rgba(var(--center-channel-color-rgb), 0.56)}.SaveChangesPanel__message.error,.SaveChangesPanel__message.saved{color:var(--button-color)}.SaveChangesPanel__message.error svg,.SaveChangesPanel__message.saved svg{color:var(--button-color)}.SaveChangesPanel__btn-ctr{display:flex;flex:1 1 auto;justify-content:flex-end}.SaveChangesPanel__btn-ctr #panelCloseButton{color:rgba(var(--button-color-rgb), 0.64);font-size:16px}.SaveChangesPanel__cancel-btn.btn.error{background:rgba(var(--button-color-rgb), 0.12);color:var(--button-color)}.SaveChangesPanel__cancel-btn.btn.error:hover{background-color:rgba(var(--button-color-rgb), 0.16)}.SaveChangesPanel__save-btn.btn.error{background-color:var(--button-color);color:var(--dnd-indicator)}.SaveChangesPanel__save-btn.btn.error:hover{background-color:rgba(var(--button-color-rgb), 0.9)}.SaveChangesPanel__save-btn.btn.error:disabled{background:rgba(var(--button-color-rgb), 0.16)}
.ChannelAccessRulesConfirmModal .modal-body{padding:0}.ChannelAccessRulesConfirmModal .filter-controls{border:none !important}.ChannelAccessRulesConfirmModal .more-modal__details{display:flex}.ChannelAccessRulesConfirmModal .more-modal__details .more-modal__description{display:flex;align-items:center}.ChannelAccessRulesConfirmModal .GenericModal__header__text_container{display:flex;gap:12px}.ChannelAccessRulesConfirmModal .GenericModal__header__text_container .GenericModal__header{display:flex;align-items:center}.ChannelAccessRulesConfirmModal .GenericModal__header__text_container .modal-subheading-container{padding-left:12px;border-left:1px solid rgba(var(--center-channel-color-rgb), 0.16)}.ChannelAccessRulesConfirmModal__summary{padding:0px 32px}.ChannelAccessRulesConfirmModal__message{margin-bottom:16px;color:var(--center-channel-color);font-size:14px;line-height:20px}.ChannelAccessRulesConfirmModal__message strong{font-weight:600}.ChannelAccessRulesConfirmModal__question{margin-bottom:24px;color:var(--center-channel-color);font-size:14px;line-height:20px}.ChannelAccessRulesConfirmModal__details{display:flex;height:500px;flex-direction:column}.ChannelAccessRulesConfirmModal__details .ChannelAccessRulesConfirmModal__buttons{margin:0 32px}.ChannelAccessRulesConfirmModal__details .ChannelAccessRulesConfirmModal__message{padding:0 32px}.ChannelAccessRulesConfirmModal__tabs{display:flex;padding:0 32px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.16)}.ChannelAccessRulesConfirmModal__tab{position:relative;padding:16px 0;border:none;margin-right:32px;background:none;color:rgba(var(--center-channel-color-rgb), 0.64);cursor:pointer;font-size:14px;font-weight:600;transition:color .15s ease}.ChannelAccessRulesConfirmModal__tab:hover{color:var(--center-channel-color)}.ChannelAccessRulesConfirmModal__tab.active{color:var(--button-bg)}.ChannelAccessRulesConfirmModal__tab.active::after{position:absolute;right:0;bottom:-1px;left:0;height:2px;background-color:var(--button-bg);content:""}.ChannelAccessRulesConfirmModal__tab:focus{outline:none}.ChannelAccessRulesConfirmModal__search{padding:16px 32px 0}.ChannelAccessRulesConfirmModal__search .form-control{width:100%}.ChannelAccessRulesConfirmModal__userList{flex:1;padding:16px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08);overflow-y:auto}.ChannelAccessRulesConfirmModal__userList .member-count{padding:8px 0}.ChannelAccessRulesConfirmModal__users{display:flex;flex-direction:column;gap:8px}.ChannelAccessRulesConfirmModal__user{display:flex;align-items:center;padding:12px 16px;border:1px solid rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px;background:var(--center-channel-bg);transition:background-color .15s ease}.ChannelAccessRulesConfirmModal__user:hover{background:rgba(var(--center-channel-color-rgb), 0.04)}.ChannelAccessRulesConfirmModal__userInfo{min-width:0;flex:1}.ChannelAccessRulesConfirmModal__userName{margin-bottom:2px;color:var(--center-channel-color);font-size:14px;font-weight:600}.ChannelAccessRulesConfirmModal__userDetails{display:flex;align-items:center;color:rgba(var(--center-channel-color-rgb), 0.64);font-size:12px;gap:8px}.ChannelAccessRulesConfirmModal__userEmail::before{margin-right:8px;content:"•"}.ChannelAccessRulesConfirmModal__noResults{display:flex;height:200px;align-items:center;justify-content:center;color:rgba(var(--center-channel-color-rgb), 0.64);font-size:14px}.ChannelAccessRulesConfirmModal__buttons{display:flex;align-items:center;justify-content:space-between;padding:24px 0;gap:8px}.ChannelAccessRulesConfirmModal__buttons__left{display:flex;gap:8px}.ChannelAccessRulesConfirmModal__buttons__right{display:flex;gap:8px}@media screen and (max-width: 768px){.ChannelAccessRulesConfirmModal__details{height:400px}.ChannelAccessRulesConfirmModal__tabs{padding:0 16px}.ChannelAccessRulesConfirmModal__details .ChannelAccessRulesConfirmModal__message{padding:16px 16px 0}.ChannelAccessRulesConfirmModal__search{padding:16px 16px 0}.ChannelAccessRulesConfirmModal__userList{padding:16px 16px 0}.ChannelAccessRulesConfirmModal__buttons{flex-direction:column;padding:12px 16px;gap:12px}.ChannelAccessRulesConfirmModal__buttons__left,.ChannelAccessRulesConfirmModal__buttons__right{justify-content:center}.ChannelAccessRulesConfirmModal__buttons .btn{min-width:0;flex:1}}
.channel-activity-warning-content .warning-description{padding-bottom:20px;border-bottom:1px solid var(--center-channel-color-16);margin-bottom:20px;color:var(--center-channel-color);font-family:"Open Sans",sans-serif;font-size:14px;font-weight:400;line-height:20px}.ConfirmModal .activity-warning-checkbox{margin-top:20px}.ConfirmModal .activity-warning-checkbox label{display:flex;align-items:flex-start;padding-left:0;margin-bottom:0;color:var(--center-channel-color);cursor:pointer;font-size:14px;font-weight:600;gap:12px;line-height:20px;user-select:none}.ConfirmModal .activity-warning-checkbox input[type=checkbox]{position:inherit;display:grid;width:1.6rem;height:1.6rem;flex-shrink:0;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);border-radius:3px;margin:0;margin-top:4px;-webkit-appearance:none;appearance:none;background-color:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.24);cursor:pointer;font:inherit;place-content:center;-webkit-transition:background-color 200ms ease-out;-moz-transition:background-color 200ms ease-out;-o-transition:background-color 200ms ease-out;transition:background-color 200ms ease-out}.ConfirmModal .activity-warning-checkbox input[type=checkbox]::before{width:10px;height:10px;background:var(--button-color);clip-path:polygon(0% 57%, 32% 88%, 100% 20%, 88% 8%, 32% 64%, 12% 45%);content:"";transform:scale(0);transform-origin:center center;transition:200ms transform ease-in-out}.ConfirmModal .activity-warning-checkbox input[type=checkbox]:checked::before{transform:scale(1)}.ConfirmModal .activity-warning-checkbox input[type=checkbox]:checked{border-color:var(--button-bg);background:var(--button-bg)}.ConfirmModal .activity-warning-checkbox input[type=checkbox]:disabled{cursor:not-allowed;opacity:.5}
.ChannelSettingsModal__accessRulesTab{display:flex;max-height:100%;flex:1;flex-direction:column;padding-bottom:60px;overflow-y:auto}.ChannelSettingsModal__systemPolicies{margin-bottom:20px}.ChannelSettingsModal__accessRulesHeader{display:flex;flex-direction:column;margin-bottom:16px;gap:8px}.ChannelSettingsModal__accessRulesEditor .table-editor__cell button{color:var(--center-channel-color) !important}.ChannelSettingsModal__accessRulesEditor .table-editor__cell button:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08) !important}.ChannelSettingsModal__accessRulesEditor .editor__help-text{width:75%;color:rgba(var(--center-channel-color-rgb), 0.56) !important}.ChannelSettingsModal__accessRulesTitle{margin:0;color:var(--center-channel-color);font-family:Metropolis,sans-serif;font-size:20px;font-weight:600;line-height:28px}.ChannelSettingsModal__accessRulesSubtitle{margin:0;color:rgba(var(--center-channel-color-rgb), 0.72);font-family:"Open Sans",sans-serif;font-size:12px;font-weight:400;line-height:20px}.ChannelSettingsModal__divider{border:none;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.16);margin:24px 0}.ChannelSettingsModal__autoSyncCheckboxContainer{display:flex;align-items:center;margin-bottom:8px;gap:8px}.ChannelSettingsModal__autoSyncLabel{display:flex;align-items:center;margin:0;cursor:pointer;user-select:none}.ChannelSettingsModal__autoSyncCheckbox{display:grid;width:1.6rem;height:1.6rem;flex-shrink:0;border:1px solid rgba(var(--center-channel-color-rgb), 0.24);border-radius:3px;margin:0;-webkit-appearance:none;appearance:none;background-color:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.24);cursor:pointer;font:inherit;place-content:center;-webkit-transition:background-color 200ms ease-out;-moz-transition:background-color 200ms ease-out;-o-transition:background-color 200ms ease-out;transition:background-color 200ms ease-out}.ChannelSettingsModal__autoSyncCheckbox::before{width:10px;height:10px;background:var(--button-color);clip-path:polygon(0% 57%, 32% 88%, 100% 20%, 88% 8%, 32% 64%, 12% 45%);content:"";transform:scale(0);transform-origin:center center;transition:200ms transform ease-in-out}.ChannelSettingsModal__autoSyncCheckbox:checked::before{transform:scale(1)}.ChannelSettingsModal__autoSyncCheckbox:checked{border-color:var(--button-bg);background:var(--button-bg)}.ChannelSettingsModal__autoSyncCheckbox:disabled{cursor:not-allowed;opacity:.5}.ChannelSettingsModal__autoSyncText{color:var(--center-channel-color);font-family:"Open Sans",sans-serif;font-size:14px;font-weight:400;line-height:20px}.ChannelSettingsModal__autoSyncText.disabled{color:rgba(var(--center-channel-color-rgb), 0.5);cursor:not-allowed}.ChannelSettingsModal__autoSyncDescription{margin:0 0 0 24px;color:rgba(var(--center-channel-color-rgb), 0.56);font-family:"Open Sans",sans-serif;font-size:12px;font-weight:400;line-height:16px}
.ShareChannelWithWorkspaces__listHeader{display:flex;font-weight:600}.ShareChannelWithWorkspaces__list{display:flex;flex-direction:column;padding:0;margin:0}.ShareChannelWithWorkspaces__item{display:flex;align-items:center;padding:8px 0px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08);gap:12px}.ShareChannelWithWorkspaces__item:first-child{border-top:1px solid rgba(var(--center-channel-color-rgb), 0.08)}.ShareChannelWithWorkspaces__itemName{overflow:hidden;flex:1;text-overflow:ellipsis;white-space:nowrap}.ShareChannelWithWorkspaces__itemStatus{flex:1;font-size:12px;font-weight:600;line-height:16px}.ShareChannelWithWorkspaces__statusPending{color:var(--error-text)}.ShareChannelWithWorkspaces__statusConnectionPending{color:rgba(var(--center-channel-color-rgb), 0.75)}.ShareChannelWithWorkspaces__statusOnline{display:flex;align-items:center;color:var(--online-indicator);gap:6px}.ShareChannelWithWorkspaces__statusOffline{color:var(--error-text)}.ShareChannelWithWorkspaces__remove{padding:4px;border:none;border-radius:4px;background:rgba(0,0,0,0);color:var(--error-text);cursor:pointer}.ShareChannelWithWorkspaces__remove:hover:not(:disabled){background:rgba(var(--center-channel-color-rgb), 0.08)}.ShareChannelWithWorkspaces__remove:disabled{cursor:not-allowed;opacity:.5}.ShareChannelWithWorkspaces__noWorkspacesMessage{color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:16px}.ShareChannelWithWorkspaces__noWorkspacesMessage .icon{font-size:14px}.ShareChannelWithWorkspaces__addBtn{align-self:flex-start}.ShareChannelWithWorkspaces__dropdown{flex:1}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}@keyframes spin{from{transform:scale(1) rotate(0deg)}to{transform:scale(1) rotate(360deg)}}@keyframes highlight{from{background:rgba(255,255,0,.5)}to{background:none}}@keyframes fadeInOpacity{0%{opacity:0}100%{opacity:1}}.ChannelSettingsModal__configurationTab{display:flex;flex-direction:column;gap:32px}.ChannelSettingsModal__configurationTab__configurationDivider{border:none;border-top:1px solid rgba(var(--center-channel-color-rgb), 0.08);margin:0}.ChannelSettingsModal__configurationTab .channel_shared_with_workspaces_container{display:flex;flex-direction:column;gap:16px}.ChannelSettingsModal__configurationTab .channel_banner_header,.ChannelSettingsModal__configurationTab .channel_translation_header,.ChannelSettingsModal__configurationTab .channel_shared_with_workspaces_header{display:flex}.ChannelSettingsModal__configurationTab .channel_banner_header .channel_banner_header__text,.ChannelSettingsModal__configurationTab .channel_banner_header .channel_translation_header__text,.ChannelSettingsModal__configurationTab .channel_banner_header .channel_shared_with_workspaces_header__text,.ChannelSettingsModal__configurationTab .channel_translation_header .channel_banner_header__text,.ChannelSettingsModal__configurationTab .channel_translation_header .channel_translation_header__text,.ChannelSettingsModal__configurationTab .channel_translation_header .channel_shared_with_workspaces_header__text,.ChannelSettingsModal__configurationTab .channel_shared_with_workspaces_header .channel_banner_header__text,.ChannelSettingsModal__configurationTab .channel_shared_with_workspaces_header .channel_translation_header__text,.ChannelSettingsModal__configurationTab .channel_shared_with_workspaces_header .channel_shared_with_workspaces_header__text{display:flex;flex:1;flex-direction:column;gap:8px}.ChannelSettingsModal__configurationTab .channel_banner_header .channel_banner_header__text span.heading,.ChannelSettingsModal__configurationTab .channel_banner_header .channel_translation_header__text span.heading,.ChannelSettingsModal__configurationTab .channel_banner_header .channel_shared_with_workspaces_header__text span.heading,.ChannelSettingsModal__configurationTab .channel_translation_header .channel_banner_header__text span.heading,.ChannelSettingsModal__configurationTab .channel_translation_header .channel_translation_header__text span.heading,.ChannelSettingsModal__configurationTab .channel_translation_header .channel_shared_with_workspaces_header__text span.heading,.ChannelSettingsModal__configurationTab .channel_shared_with_workspaces_header .channel_banner_header__text span.heading,.ChannelSettingsModal__configurationTab .channel_shared_with_workspaces_header .channel_translation_header__text span.heading,.ChannelSettingsModal__configurationTab .channel_shared_with_workspaces_header .channel_shared_with_workspaces_header__text span.heading{color:rgb(var(--center-channel-color-rgb));font-size:16px}.ChannelSettingsModal__configurationTab .channel_banner_header .channel_banner_header__text span.subheading,.ChannelSettingsModal__configurationTab .channel_banner_header .channel_translation_header__text span.subheading,.ChannelSettingsModal__configurationTab .channel_banner_header .channel_shared_with_workspaces_header__text span.subheading,.ChannelSettingsModal__configurationTab .channel_translation_header .channel_banner_header__text span.subheading,.ChannelSettingsModal__configurationTab .channel_translation_header .channel_translation_header__text span.subheading,.ChannelSettingsModal__configurationTab .channel_translation_header .channel_shared_with_workspaces_header__text span.subheading,.ChannelSettingsModal__configurationTab .channel_shared_with_workspaces_header .channel_banner_header__text span.subheading,.ChannelSettingsModal__configurationTab .channel_shared_with_workspaces_header .channel_translation_header__text span.subheading,.ChannelSettingsModal__configurationTab .channel_shared_with_workspaces_header .channel_shared_with_workspaces_header__text span.subheading{color:rgba(var(--center-channel-color-rgb), 0.64);font-size:12px}.ChannelSettingsModal__configurationTab .channel_banner_section_body,.ChannelSettingsModal__configurationTab .channel_shared_with_workspaces_section_body{animation-duration:.3s;animation-iteration-count:1;animation-name:fadeInOpacity;animation-timing-function:ease-in;opacity:1;display:flex;width:100%;flex-direction:column;gap:16px}.ChannelSettingsModal__configurationTab .AdvancedTextbox{width:390px}.ChannelSettingsModal__configurationTab .AdvancedTextbox #PreviewInputTextButton{position:absolute;z-index:10;top:5px;right:5px}.ChannelSettingsModal__configurationTab .AdvancedTextbox #channel_banner_banner_text_textbox{min-height:40px;max-height:200px}.ChannelSettingsModal__configurationTab .AdvancedTextbox .textbox-preview-area{height:max-content !important;max-height:200px;overflow-y:auto}.ChannelSettingsModal__configurationTab .AdvancedTextbox .textbox-preview-area .markdown__heading{overflow:hidden;margin:2px;font-size:18px;text-overflow:ellipsis}.ChannelSettingsModal__configurationTab .setting_section{display:flex;flex-direction:row;gap:12px}.ChannelSettingsModal__configurationTab .setting_section .color-input.input-group{width:160px}.ChannelSettingsModal__configurationTab .setting_section span.setting_title{flex:1;padding-top:12px;color:rgb(var(--center-channel-color-rgb));font-size:12px;font-weight:600}.ChannelSettingsModal__configurationTab .setting_section .setting_body{flex:4}.ChannelSettingsModal__configurationTab .setting_section .AdvancedTextbox{margin-top:0 !important}
.ChannelSettingsModal{width:920px !important}.ChannelSettingsModal__infoTabTitle{margin-bottom:4px;color:var(--center-channel-color);font-family:Metropolis,sans-serif;font-size:16px;font-weight:600;line-height:20px}.ChannelSettingsModal label.Input_subheading{color:rgba(var(--center-channel-color-rgb), 0.64);font-family:Open Sans,sans-serif;font-size:12px;font-weight:400}.ChannelSettingsModal .GenericModal__wrapper{display:flex;overflow:visible;max-width:1200px;max-height:90vh;flex-direction:column;border:var(--border-default);border-radius:var(--radius-l);box-shadow:var(--elevation-6)}.ChannelSettingsModal .GenericModal__wrapper .modal-body{display:flex;width:auto;min-height:150px;flex-direction:column;margin:0;gap:24px;overflow-y:auto}.ChannelSettingsModal__bodyWrapper{display:flex;width:100%;max-width:920px;flex-direction:column;gap:24px}.ChannelSettingsModal .settings-table{display:flex;flex-direction:row}.ChannelSettingsModal .settings-table .settings-links{min-width:200px}.ChannelSettingsModal .settings-table .settings-content{display:flex;overflow:visible !important;flex:1;flex-direction:column;padding:0 32px}.ChannelSettingsModal .settings-table .settings-content .AdvancedTextbox{position:relative}.ChannelSettingsModal .settings-table .settings-content .channel-settings-name-container,.ChannelSettingsModal .settings-table .settings-content .AdvancedTextbox{margin-top:24px}.ChannelSettingsModal__infoTab{display:flex;flex-direction:column;padding-bottom:60px}.ChannelSettingsModal__infoTab #PreviewInputTextButton{position:absolute;z-index:10;top:5px;right:5px}.ChannelSettingsModal__infoTab .textbox-preview-area,.ChannelSettingsModal__infoTab #channel_settings_purpose_textbox,.ChannelSettingsModal__infoTab #channel_settings_header_textbox{height:80px !important;border:none !important;box-shadow:none !important}.ChannelSettingsModal__infoTab .suggestion-list{z-index:100000}.ChannelSettingsModal__infoTab .textbox-preview-area{box-shadow:none}.ChannelSettingsModal__typeSelector{margin-top:16px}.ChannelSettingsModal__purposeContainer,.ChannelSettingsModal__headerContainer{margin-top:28px}.ChannelSettingsModal__purposeContainer textarea,.ChannelSettingsModal__headerContainer textarea{width:100%;min-height:8em;max-height:60vh;box-sizing:border-box;padding:12px 16px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;background:var(--center-channel-bg);color:var(--center-channel-color);font-size:14px;line-height:20px;resize:none}.ChannelSettingsModal__purposeContainer textarea:hover,.ChannelSettingsModal__headerContainer textarea:hover{border-color:rgba(var(--center-channel-color-rgb), 0.48)}.ChannelSettingsModal__purposeContainer textarea:focus,.ChannelSettingsModal__headerContainer textarea:focus{border-color:var(--button-bg);box-shadow:inset 0 0 0 1px var(--button-bg)}.ChannelSettingsModal__purposeContainer textarea.with-error,.ChannelSettingsModal__headerContainer textarea.with-error{border-color:var(--error-text)}.ChannelSettingsModal__purposeContainer textarea.with-error:focus,.ChannelSettingsModal__headerContainer textarea.with-error:focus{box-shadow:inset 0 0 0 1px var(--error-text)}.ChannelSettingsModal__headerContainer{margin-top:28px}.ChannelSettingsModal__headerContainer--preview-button{display:flex;align-items:center;padding:4px 8px;border:none;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.56);cursor:pointer}.ChannelSettingsModal__headerContainer--preview-button:hover{color:rgba(var(--center-channel-color-rgb), 0.72)}.ChannelSettingsModal__headerContainer--preview-button i{font-size:18px}.ChannelSettingsModal__headerContainer .markdown-preview-wrapper{border:1px solid rgba(var(--center-channel-color-rgb), 0.16)}.ChannelSettingsModal__archiveTab{display:flex;flex-direction:column;gap:16px}.ChannelSettingsModal__archiveTab .btn-danger{align-self:flex-start}@media screen and (max-width: 768px){.ChannelSettingsModal{max-width:100%;margin:0}.ChannelSettingsModal .modal-content{display:flex;height:100vh;max-height:unset;flex-direction:column;border-radius:unset}}@media screen and (max-height: 900px)and (min-width: 768px){.ChannelSettingsModal .modal-content{max-height:90vh}}@media screen and (max-height: 600px){.ChannelSettingsModal .modal-content,.ChannelSettingsModal .GenericModal__wrapper{max-height:85vh !important}}.ChannelSettingsModal .SaveChangesPanel{width:70%}@media screen and (max-width: 768px){.ChannelSettingsModal .SaveChangesPanel{width:75%}}.archiveChannelConfirmModal{display:flex;flex-direction:column;justify-content:center}.archiveChannelConfirmModal .GenericModal__header{display:flex;justify-content:center}.archiveChannelConfirmModal .GenericModal__header h1#genericModalLabel{width:auto}.archiveChannelConfirmModal .GenericModal__body .ConfirmModal__body{text-align:center}.archiveChannelConfirmModal .ConfirmModal__footer{display:flex;justify-content:center;gap:8px}
.channel-members-rhs__members-container{flex:1 1 auto;padding:0 4px 16px}.channel-members-rhs__member-list-separator{padding:0px 12px;margin-top:16px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;font-weight:600;letter-spacing:.02em;line-height:28px;text-transform:uppercase}.channel-members-rhs__member-list-separator--first{margin-top:0px}.channel-members-rhs__alert-container{padding:0 20px 15px}.channel-members-rhs__alert-container.policy-enforced{padding:0}.channel-members-rhs__alert-container.policy-enforced .AlertBanner{padding-bottom:8px;border:none;border-radius:0;border-bottom:1px solid var(--center-channel-color-8, rgba(63, 67, 80, 0.08))}.channel-members-rhs__alert-container.policy-enforced .TagGroup{margin-top:12px}.channel-members-rhs__member{display:flex;flex-direction:row;align-items:center;padding:8px 16px;border-radius:4px}.channel-members-rhs__member:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.75)}.channel-members-rhs__member:hover .channel-members-rhs__send-message{display:block;flex:0 0 auto}.channel-members-rhs__member .ProfileSpan{display:flex;width:100%;flex-direction:row;align-items:center;padding:4px 0}.channel-members-rhs__member .ProfileSpan .profileSpan_userInfo{display:flex;overflow:hidden;flex-grow:1;cursor:pointer;text-overflow:ellipsis;white-space:nowrap}.channel-members-rhs__member .MenuWrapper{font-size:11px;font-weight:600}.channel-members-rhs__avatar{flex-basis:fit-content;flex-shrink:0}.channel-members-rhs__display-name{display:inline;overflow:hidden;margin-left:8px;color:var(--center-channel-color);font-size:14px;gap:8px;line-height:20px;text-overflow:ellipsis}.channel-members-rhs__username{margin-left:4px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:18px}.channel-members-rhs__send-message{display:none;width:24px;height:24px;padding:0;border:0;border-radius:4px;margin-left:8px;background-color:rgba(0,0,0,0)}.channel-members-rhs__send-message:hover{background-color:rgba(var(--center-channel-color-rgb), 0.12)}.channel-members-rhs__send-message .icon{color:rgba(var(--center-channel-color-rgb), 0.64);font-size:14.4px}.channel-members-rhs__role-chooser{display:none;flex-basis:fit-content;flex-shrink:0}.channel-members-rhs__role-chooser.editing{display:block}.channel-members-rhs__role-chooser .MenuWrapper{padding:6px 10px;border-radius:4px}.channel-members-rhs__role-chooser .MenuWrapper.MenuWrapper--open{background:rgba(var(--button-bg-rgb), 0.16)}.channel-members-rhs__role-chooser .MenuWrapper:not(.MenuWrapper--open):hover{background:rgba(var(--center-channel-color-rgb), 0.08)}.channel-members-rhs__shared-icon{margin:0 0 0 4px;font-size:16px;line-height:20px}
@media(min-width: 758px){#restorePostModal .modal-dialog,#restorePostModal .modal-content{width:832px}#restorePostModal .modal-content{max-width:100%}}
.edit-post-history__container .edit-post-history__icon__button.toggleCollapseButton{border:none;background:none;pointer-events:none}.edit-post-history__container .edit-post-history__icon__button.restore-icon{width:28px;height:28px;border:none;border-radius:4px;background:none}.edit-post-history__container .edit-post-history__icon__button.restore-icon:hover{background-color:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.75)}.edit-post-history__container .edit-post-history__icon__button.restore-icon i.icon.icon-restore{width:16px;height:16px}.edit-post-history__container .post-image__columns .post-image__column,.edit-post-history__container .post-image__columns .post-image__thumbnail{cursor:default}
.sidebar-right__edit-post-history .simplebar-content{display:flex;flex-direction:column}.edit-post-history__error_container{display:flex;flex:1;align-items:center;justify-content:center}.edit-post-history__error_item{display:flex;flex-direction:column;align-items:center;justify-content:center;padding:56px;text-align:center}.edit-post-history__error_heading{color:var(--center-channel-color);font-size:20px;font-weight:600;line-height:28px}.edit-post-history__error_subheading{color:rgba(var(--center-channel-color-rgb), 0.75);font-weight:400}
.Header{display:flex;height:56px;align-items:center;justify-content:space-between;padding:0 16px;border-radius:12px 12px 0 0;background-color:var(--center-channel-bg)}.Header h1,.Header h2,.Header h3,.Header h4,.Header h5,.Header h6{margin:0;line-height:1}.Header h2{color:rgba(var(--center-channel-color-rgb), 1);font-size:16px;font-weight:600}.Header>div{display:flex}.Header>div p{margin:0 0 0 8px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;font-weight:400;line-height:16px}.Header>.spacer{flex:1}
.ThreadPane{display:grid;grid-template-areas:"header" "pane";grid-template-rows:56px 1fr}.ThreadPane .Header{display:flex;height:56px;align-items:center;justify-content:space-between;padding:12px 16px;border-bottom:var(--border-default);gap:4px;grid-area:header;--button-separator-height: 24px}.ThreadPane .Header .left{display:flex}.ThreadPane .Header .back{display:none;flex-shrink:0}.ThreadPane .Header .back.hasBackAction{display:unset}.ThreadPane .Header .FollowButton,.ThreadPane .Header h3 .Button{height:24px;padding:4px 8px;font-size:12px;line-height:16px}.ThreadPane .Header h3{display:inline-grid;align-items:center;margin:0 10px 0 0;color:rgba(var(--center-channel-color-rgb), 1);grid-template-columns:max-content 1fr}.ThreadPane .Header h3>span{padding-right:8px;padding-left:4px;font-size:16px;font-weight:600;line-height:32px;vertical-align:top}.ThreadPane .Header h3 .Button{color:rgba(var(--center-channel-color-rgb), 0.75);font-weight:400}.ThreadPane .Header .btn:focus-visible,.ThreadPane .Header .btn[aria-expanded=true]{border-radius:4px;box-shadow:0 0 1px 3px rgba(var(--link-color-rgb), 0.5),0 0 0 1px var(--link-color)}.ThreadPane .Header .PopoutButton{margin-left:4px}.ThreadPane .ThreadViewer{overflow:hidden;grid-area:pane}.ThreadPane .ThreadViewer .post-right__scroll{padding-top:0}
.FileSearchResultItem{display:flex;overflow:hidden;max-width:600px;flex-direction:row;flex-grow:1;align-items:center;padding:11px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:4px;margin:0 14px 8px 14px;background:rgba(0,0,0,0);color:var(--center-channel-color);cursor:pointer;transition:box-shadow .15s ease}.FileSearchResultItem .Menu__content{border:1px solid rgba(var(--center-channel-color-rgb), 0.16);background-color:var(--center-channel-bg)}.FileSearchResultItem:hover,.FileSearchResultItem:focus-within,.FileSearchResultItem.keep-open{overflow:visible;box-shadow:0 2px 3px 0 rgba(0,0,0,.1),0 2px 3px 0 rgba(0,0,0,.1)}.FileSearchResultItem:hover .action-icon,.FileSearchResultItem:focus-within .action-icon,.FileSearchResultItem.keep-open .action-icon{display:flex;opacity:1}.FileSearchResultItem:hover .MenuWrapper,.FileSearchResultItem:focus-within .MenuWrapper,.FileSearchResultItem.keep-open .MenuWrapper{display:block;opacity:1}.FileSearchResultItem:hover .fileData,.FileSearchResultItem:focus-within .fileData,.FileSearchResultItem.keep-open .fileData{overflow:hidden}.FileSearchResultItem .file-icon{width:4rem;min-width:4rem;height:4rem}.FileSearchResultItem .fileData{display:flex;min-width:0;flex-direction:column;flex-grow:1;padding:0 11px;font-size:12px;font-weight:600;text-overflow:ellipsis;white-space:nowrap}.FileSearchResultItem .fileData .fileDataName{overflow:hidden;margin-bottom:3px;text-align:left;text-overflow:ellipsis}.FileSearchResultItem .fileData .fileMetadata{display:flex;flex-direction:row;font-weight:400;gap:8px}.FileSearchResultItem .fileData .fileMetadata>:not(.Tag){opacity:.73}.FileSearchResultItem .fileData .fileMetadata .Tag{max-width:100px}.FileSearchResultItem .post-image{min-width:4rem}.FileSearchResultItem .action-icon{display:none;margin-left:2px}.FileSearchResultItem .action-icon.download-icon{margin-right:2px}.FileSearchResultItem .action-icon svg{display:flex}.FileSearchResultItem .MenuWrapper{display:flex;opacity:0}
.FilesFilterMenu .MenuWrapper{z-index:100;align-self:end}.FilesFilterMenu .MenuWrapper .action-icon{z-index:5;display:flex;min-width:32px;height:32px;align-items:center;justify-content:center;padding:0;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.75);cursor:pointer;text-align:center}.FilesFilterMenu .MenuWrapper .action-icon .icon-dot{position:absolute;top:6px;right:6px;width:10px;height:10px;border:2px solid var(--center-channel-bg);border-radius:50%;background-color:var(--button-bg)}.FilesFilterMenu .MenuWrapper .action-icon:hover{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.75)}.FilesFilterMenu .MenuItem span.icon{position:absolute;right:13px;color:var(--button-bg)}
@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.CenterMessageLock{display:flex;align-items:center;padding:16px;border:1px rgba(var(--center-channel-color-rgb), 0.08) solid;border-radius:4px;margin:0 16px 16px;background-color:rgba(var(--center-channel-color-rgb), 0.04);gap:12px}.CenterMessageLock__left{align-self:flex-start;padding:0}.CenterMessageLock__right{margin-top:-2px}.CenterMessageLock__description{color:rgba(var(--center-channel-color-rgb), 0.75)}.CenterMessageLock__icon{color:rgba(var(--center-channel-color-rgb), 0.64)}.CenterMessageLock__title{padding-bottom:4px;font-size:14px;font-weight:600}.CenterMessageLock__cta{padding-top:12px}.CenterMessageLock__cta .btn{display:inline-flex;align-items:center;border:0;border-radius:4px;background:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg);font-weight:600;transition:all .15s ease-out;font-size:12px}.CenterMessageLock__cta .btn:disabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32)}.CenterMessageLock__cta .btn:hover:enabled{background:rgba(var(--button-bg-rgb), 0.12)}.CenterMessageLock__cta .btn:active:enabled{background:rgba(var(--button-bg-rgb), 0.16)}.CenterMessageLock__cta .btn i{display:flex;font-size:18px}.CenterMessageLock__cta .btn i:first-child::before{margin:0 7px 0 0}.CenterMessageLock__cta .btn i:last-child::before{margin:0 0 0 7px}.CenterMessageLock__cta .btn:hover,.CenterMessageLock__cta .btn:focus{color:var(--button-color)}.CenterMessageLock__cta .btn:focus{border:0}.CenterMessageLock__cta .btn.is-admin{position:relative;display:inline-flex;align-items:center;justify-content:center;border:0;border-radius:4px;background:var(--button-bg);color:var(--button-color);font-weight:600;transition:all .15s ease-out}.CenterMessageLock__cta .btn.is-admin:hover{background:linear-gradient(0deg, rgba(0, 0, 0, 0.08), rgba(0, 0, 0, 0.08)),var(--button-bg)}.CenterMessageLock__cta .btn.is-admin:active{background:linear-gradient(0deg, rgba(0, 0, 0, 0.16), rgba(0, 0, 0, 0.16)),var(--button-bg)}.CenterMessageLock__cta .btn.is-admin:focus{box-sizing:border-box;border:2px solid var(--sidebar-text-active-border);outline:none}.CenterMessageLock__cta .btn.is-admin:disabled:not(.always-show-enabled){background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed}.CenterMessageLock__cta .btn.is-admin i{display:flex;font-size:18px}.CenterMessageLock__cta .btn.is-admin:hover,.CenterMessageLock__cta .btn.is-admin:focus{color:var(--button-color)}.CenterMessageLock__cta .btn.is-admin:focus{border:0}
.MessagesOrFilesSelector{display:flex;align-items:center;padding:7px 16px 7px 14px;border-bottom:1px solid rgba(var(--center-channel-color-rgb), 0.08)}.MessagesOrFilesSelector .buttons-container{flex-grow:1;margin:7px 0}.MessagesOrFilesSelector .tab{padding:4px 12px;border:0;border-radius:4px;margin-right:4px;background-color:rgba(var(--center-channel-bg-rgb), 1);color:rgba(var(--center-channel-color-rgb), 0.75);cursor:pointer;font-weight:600;text-decoration:none}.MessagesOrFilesSelector .tab.active{border-radius:4px;background-color:rgba(var(--button-bg-rgb), 0.08);color:var(--button-bg)}.MessagesOrFilesSelector .tab.active .counter{background-color:rgba(var(--button-bg-rgb), 0.08)}.MessagesOrFilesSelector .tab .counter{position:relative;bottom:1px;padding:1px 6px;border-radius:8px;margin-left:4px;background-color:rgba(var(--center-channel-color-rgb), 0.08);font-size:10px;font-weight:700}
.SearchLimitsBanner__wrapper{padding-top:16px}
.SearchResults .messages-or-files .active{background-color:rgba(var(--buton-bg-rgb), 0.08)}.SearchResults .messages-or-files a{padding:4px 12px;margin-left:10px;text-decoration:none}.SearchResults .channel-files__header{display:flex;align-items:center;justify-content:space-between;padding:7px 14px}.SearchResults .channel-files__header .channel-files__title{font-size:14px;font-weight:600}.SearchResults .channel-files-container{padding-top:0}

/*# sourceMappingURL=4038.ae1d462773f6d51e667b.css.map*/