"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[1428],{71428:(e,a,t)=>{t.r(a),t.d(a,{default:()=>E});var n=t(71633),r=t.n(n),s=t(36418),l=t.n(s),i=t(14778),d=t(37270),o=t(81911),c=t(71892),m=t(77440),u=t(62563),h=t(2386),b=t(75270),p=t(45697),_=t(78451),C=t(3295);const k=e=>l().createElement("svg",Object.assign({width:"18",height:"18",viewBox:"0 0 14 13",fill:"none",xmlns:"http://www.w3.org/2000/svg"},e),l().createElement("path",{d:"M11.7952 0.00524884C12.1312 0.00524884 12.4144 0.125249 12.6448 0.365248C12.8848 0.595648 13.0048 0.878848 13.0048 1.21485V8.41485C13.0048 8.75085 12.8848 9.03405 12.6448 9.26445C12.4144 9.49485 12.1312 9.61005 11.7952 9.61005H3.4L0.9952 12.0148V1.21485C0.9952 0.878848 1.1104 0.595648 1.3408 0.365248C1.5808 0.125249 1.8688 0.00524884 2.2048 0.00524884H11.7952ZM2.2048 1.21485V9.10605L2.896 8.41485H11.7952V1.21485H2.2048ZM3.4 3.01485H10.6V4.21005H3.4V3.01485ZM3.4 5.40525H8.8V6.61485H3.4V5.40525Z"}));var g=t(3490);const E=()=>{const{formatMessage:e}=(0,i.useIntl)(),a=(0,d.useDispatch)(),t=(0,d.useSelector)(m.WW),{url:n}=(0,o.useRouteMatch)(),{pathname:E}=(0,o.useLocation)(),L=null!=(0,o.matchPath)(E,{path:"/:team/threads/:threadIdentifier?"}),{currentTeamId:f,currentUserId:w}=(0,g.K)(),v=(0,d.useSelector)(u.kL),H=v?.total_unread_threads,S=(0,d.useSelector)(b.A),I=(0,d.useSelector)(b.bM),M=(0,s.useCallback)((e=>{e.stopPropagation(),performance.mark(C.CU.GlobalThreadsLinkClicked),S&&I===_._n.EDIT_HISTORY&&a((0,h.bP)())}),[S,I]);return(0,s.useEffect)((()=>{t&&a((0,c.H_)(w,f))}),[w,f,t]),t?l().createElement("ul",{className:"SidebarGlobalThreads NavGroupContent nav nav-pills__container"},l().createElement("li",{id:"sidebar-threads-button",className:r()("SidebarChannel",{active:L,unread:H}),tabIndex:-1},l().createElement(o.Link,{onClick:M,to:`${n}/threads`,id:"sidebarItem_threads",draggable:"false",className:r()("SidebarLink sidebar-item",{"unread-title":Boolean(H)}),tabIndex:0},l().createElement("span",{className:"icon"},l().createElement(k,null)),l().createElement("div",{className:"SidebarChannelLinkLabel_wrapper"},l().createElement("span",{className:"SidebarChannelLinkLabel sidebar-item__name"},e({id:"globalThreads.sidebarLink",defaultMessage:"Threads"}))),v?.total_unread_mentions>0&&l().createElement(p.A,{unreadMentions:v.total_unread_mentions,hasUrgent:Boolean(v?.total_unread_urgent_mentions)})))):null}}}]);
//# sourceMappingURL=1428.78d2facb9e6ef9647449.js.map