.app__body .modal .GenericModal.channel-bookmarks-create-modal .modal-body .form-control{height:40px;border:unset}.channel-bookmarks-create-modal .linkInput{margin-bottom:3rem;color:rgba(var(--center-channel-color-rgb), 0.72)}.channel-bookmarks-create-modal .Input___customMessage{line-height:14px}.channel-bookmarks-create-modal .LoadingSpinner{padding:10px 12px;font-size:16px}
.channel-bookmarks-container{scrollbar-width:thin}.channelBookmarksMenuButton{position:relative;display:flex;padding:4px;border:none;border-radius:4px;background:rgba(0,0,0,0);color:rgba(var(--center-channel-color-rgb), 0.56);font-family:Open Sans;font-size:12px;font-weight:600;gap:5px}.channelBookmarksMenuButton.withLabel{padding:4px 12px 4px 6px;border-radius:12px}.channelBookmarksMenuButton[disabled]{background:rgba(var(--center-channel-color-rgb), 0.04);color:rgba(var(--center-channel-color-rgb), 0.56)}.channelBookmarksMenuButton:hover:enabled{background:rgba(var(--center-channel-color-rgb), 0.08);color:rgba(var(--center-channel-color-rgb), 0.72)}.channelBookmarksMenuButton:active:enabled,.channelBookmarksMenuButton[aria-expanded=true]{background:rgba(var(--button-bg-rgb), 0.08);color:rgb(var(--button-bg-rgb))}.channelBookmarksDotMenuButton{display:flex;width:18px;height:18px;align-items:center;padding:0;border:none;border-radius:4px;background:rgba(var(--center-channel-color-rgb), 8%);background:color-mix(in sRGB, var(--center-channel-bg), var(--center-channel-color) 8%);color:rgba(var(--center-channel-color-rgb), 0.56);font-family:Open Sans;font-size:12px;font-weight:600}.channelBookmarksDotMenuButton:hover{background:rgba(var(--button-bg-rgb), 16%);background:color-mix(in sRGB, var(--center-channel-bg), var(--center-channel-color) 16%);color:rgba(var(--center-channel-color-rgb), 0.72)}.channelBookmarksDotMenuButton:active,.channelBookmarksDotMenuButton[aria-expanded=true]{background:rgba(var(--button-bg-rgb), 16%);background:color-mix(in sRGB, var(--center-channel-bg), var(--button-bg) 16%);color:rgb(var(--button-bg-rgb))}#bookmark-create-file-input,#bookmark-create-file-input-in-modal{display:none}

/*# sourceMappingURL=1119.e126b68a8974a8b18ebe.css.map*/