button.call-button{display:flex;height:32px;align-items:center;justify-content:center;padding:10px 12px;border-radius:4px;color:rgb(var(--button-bg-rgb));fill:currentColor}button.call-button:hover{background:rgba(var(--button-bg-rgb), 0.08)}button.call-button:active,button.call-button.active{background:rgba(var(--button-bg-rgb), 0.16)}button.call-button i,button.call-button span{font-size:14px;line-height:14px}button.call-button i::before,button.call-button span::before{margin:0}button.call-button svg{width:14px;height:14px}button.call-button span.call-button-label{padding:1px 0;margin:0 6px;font-size:12px;font-weight:600;line-height:9px}button.call-button.dropdown{color:rgba(var(--center-channel-color-rgb), 0.75);fill:currentColor}button.call-button.disabled{color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed;fill:currentColor}button.call-button.disabled:hover{background:none}button.call-button.disabled:active{background:none}.Menu .MenuItem>button.call-button-dropdown{display:flex;padding:6px 20px 6px 16px;margin:0;color:rgb(var(--button-bg-rgb));font-size:14px;line-height:20px}.Menu .MenuItem>button.call-button-dropdown svg{width:16px;height:16px;align-self:flex-start;margin-right:12px;margin-left:4px;fill:currentColor}.Menu .MenuItem>button.call-button-dropdown i{align-self:flex-start;margin-right:12px;margin-left:4px;color:inherit;font-size:16px}.Menu .MenuItem>button.call-button-dropdown i::before{margin:0}.Menu .MenuItem>button.call-button-dropdown .call-button-dropdown-sublabel{margin-top:4px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:12px;line-height:16px}.Menu .MenuItem>button.call-button-dropdown div{display:flex;flex-direction:column}.Menu .MenuItem>button.call-button-dropdown.disabled{color:rgba(var(--center-channel-color-rgb), 0.32);fill:currentColor}.Menu .MenuItem>button.call-button-dropdown.disabled svg{width:16px;height:16px;fill:currentColor}.Menu .MenuItem>button.call-button-dropdown.disabled i{color:inherit;font-size:16px}.Menu .MenuItem>button.call-button-dropdown.disabled i::before{margin:0}.Menu .MenuItem>button.call-button-dropdown.disabled .call-button-dropdown-sublabel{color:inherit;font-size:12px}
.channel-header-text-popover-floating-overlay{z-index:1200}.channel-header-text-popover{min-width:200px;max-width:calc(100vw - 10px);max-height:calc(100vh - 200px);padding:6px 8px;border:1px solid rgba(var(--center-channel-color-rgb), 0.16);border-radius:var(--radius-s);background:var(--center-channel-bg);box-shadow:var(--elevation-4);font-size:12px;overflow-y:auto;word-break:break-word}.channel-header-text-popover .markdown__list{margin:0}.channel-header-text-popover .markdown-inline-img{max-height:18px;border:1px solid rgba(0,0,0,0);border-radius:2px;margin:2px;cursor:pointer}.channel-header-text-popover .markdown-inline-img--loading{height:18px;visibility:hidden}.channel-header-text-popover .markdown-inline-img--hover{border:1px solid rgba(0,0,0,0)}.channel-header-text-popover .markdown-inline-img--hover:hover{box-shadow:0 2px 2px 0 rgba(0,0,0,.1),0 2px 2px 0 rgba(0,0,0,.1);transition:all .1s linear}.channel-header-text-popover .markdown-inline-img--no-border{border:unset}.channel-header-text-popover div.markdown__paragraph-inline{display:inline-block}.channel-header-text-popover .broken-image{max-height:18px;border-radius:unset}.channel-header-text-popover .image-loaded-container{display:inline-block}.channel-header-text-popover .file-preview__button{display:inline-block}.channel-header-text-popover .file-preview__button .markdown-inline-img{margin:0 2px}.channel-header-text-popover .emoticon{min-width:18px;height:18px;min-height:18px;vertical-align:text-top}.channel-header-text-popover ul+p,.channel-header-text-popover ol+p{margin-top:.6em}.channel-header-text-popover p+ul,.channel-header-text-popover p+ol{margin-top:.6em}.channel-header-text-popover blockquote{overflow:hidden;padding:0 0 0 20px;font-size:13px;text-overflow:ellipsis}.channel-header-text-popover blockquote::before{top:0;left:2px;font-size:15px}.channel-header-text-popover p{white-space:pre-wrap;word-break:normal}.channel-header-text-popover p:last-child{margin-bottom:0}
.ChannelMoveToSubMenu__disabledContainer+hr{margin-top:8px;margin-bottom:8px}
.app__body .modal .GenericModal.channel-bookmarks-create-modal .modal-body .form-control{height:40px;border:unset}.channel-bookmarks-create-modal .linkInput{margin-bottom:3rem;color:rgba(var(--center-channel-color-rgb), 0.72)}.channel-bookmarks-create-modal .Input___customMessage{line-height:14px}.channel-bookmarks-create-modal .LoadingSpinner{padding:10px 12px;font-size:16px}
#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body{display:flex;flex-direction:column;gap:20px;overflow-y:visible;transition:height 200ms ease}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body.multi-team{min-height:340px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body.single-team{height:230px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body.loading{height:152px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body.error{height:unset}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body .new-channel-modal__url{margin-top:-20px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body .loadingIndicator{display:block;width:32px;height:32px;margin:36px auto 48px;font-size:32px}#convert-gm-to-channel-modal .convert-gm-to-channel-modal-body .conversion-error{color:var(--error-text)}#convert-gm-to-channel-modal .DropDown__menu{z-index:999;max-height:120px}#convert-gm-to-channel-modal .DropDown__menu-list{z-index:999;max-height:120px}#convert-gm-to-channel-modal .modal-body{overflow:visible}#convert-gm-to-channel-modal .GenericModal__button.delete.disabled{color:var(--button-color) !important;opacity:.65}

/*# sourceMappingURL=7272.743b82d58280e053643e.css.map*/