{{define "email_info"}}

{{if .Props.SupportEmail}}
<td style="color: #999; padding-top: 20px; line-height: 25px; font-size: 13px;">
    {{.Props.EmailInfo1}}<a href='mailto:{{.Props.SupportEmail}}' style='text-decoration: none; color:#2389D7;'>{{.Props.SupportEmail}}</a><br>{{.Props.EmailInfo2}}<br>{{.Props.EmailInfo3}}<br>
</td>
{{end}}

{{end}}
