"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[5808],{25808:(e,a,n)=>{n.r(a),n.d(a,{default:()=>d});var t=n(37270),l=n(14776),o=n(7430),m=n(79751),r=n(36418),s=n.n(r),c=n(67277),i=n(11053),p=n(78451);const u={openModal:m.q},d=(0,t.connect)((function(e){const a=(0,l.H7)(e),n=(0,o.HW)(e);return{username:n?.username,teamDisplayName:a?.display_name??""}}),u)((function(e){return e.username?s().createElement("div",{className:"mobileSidebarHeader"},s().createElement("h1",null,e.teamDisplayName),s().createElement("div",{className:"mobileSidebarHeader__username"},s().createElement("span",null,"@"+e.username),s().createElement(c.A,{showTooltip:!1,emojiStyle:{verticalAlign:"top"},onClick:function(a){a.stopPropagation();const n={modalId:p.IQ.CUSTOM_STATUS,dialogType:i.A};e.openModal(n)}}))):null}))}}]);
//# sourceMappingURL=5808.764c4ddc97777b3aff5b.js.map