@keyframes emphasis-sidebar-resize-line{50%{transform:scaleX(1.5)}100%{transform:scaleX(1)}}@keyframes shake-horizontally{10%,90%{transform:translate3d(-1px, 0, 0)}20%,80%{transform:translate3d(2px, 0, 0)}30%,50%,70%{transform:translate3d(-4px, 0, 0)}40%,60%{transform:translate3d(4px, 0, 0)}}.hfroute-footer{display:flex;width:100%;max-width:1520px;height:auto;min-height:80px;flex-flow:wrap;align-items:center;align-self:center;padding:0 40px}.hfroute-footer .footer-link{border:none;box-shadow:none;color:var(--link-color);font-size:12px;font-weight:600;line-height:16px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:11px;font-weight:400;line-height:16px}.hfroute-footer .footer-link:hover,.hfroute-footer .footer-link:active,.hfroute-footer .footer-link:focus{text-decoration-line:underline}.hfroute-footer .footer-link:disabled{color:rgba(var(--center-channel-color-rgb), 0.32);cursor:not-allowed;text-decoration:none}.hfroute-footer .footer-link:not(:last-child){margin-right:24px}.hfroute-footer .footer-copyright{margin-right:24px;color:rgba(var(--center-channel-color-rgb), 0.75);font-size:11px;line-height:16px}@media screen and (max-width: 699px){.hfroute-footer{padding:0 24px}}

/*# sourceMappingURL=4602.9b492ef26a0fe59f5145.css.map*/