.preview-modal-content__sku-label{display:flex;width:fit-content;align-items:center;padding:2px 6px;border-radius:4px;margin-bottom:12px;background:rgba(var(--center-channel-color-rgb), 0.08);font-size:12px;font-weight:600;gap:4px;letter-spacing:.02em;text-transform:uppercase}.preview-modal-content__sku-label-logo{width:12px;height:16px}.preview-modal-content__sku-label-logo svg{width:100%;height:100%;fill:rgb(var(--center-channel-color-rgb))}.preview-modal-content__title{margin:0 0 8px 0;font-size:22px;font-weight:600;line-height:28px}.preview-modal-content__subtitle{min-height:60px;max-height:80px;margin-bottom:24px;overflow-y:auto}.preview-modal-content__subtitle a{text-decoration:none}.preview-modal-content__subtitle a:hover{text-decoration:underline}.preview-modal-content__media-container{display:flex;overflow:hidden;height:306px;flex:0 0 306px;align-items:center;justify-content:center;border:solid 1px rgba(var(--center-channel-color-rgb), 0.08);border-radius:4px}.preview-modal-content__media-container video{width:100%;height:100%;object-fit:contain}.preview-modal-content__media-container img{max-width:100%;max-height:100%;object-fit:contain}.preview-modal-content__media-container iframe{width:100%;height:100%;min-height:300px;align-self:stretch;border:none;border-radius:8px;box-shadow:0 2px 8px rgba(var(--center-channel-color-rgb), 0.08);transition:all .2s ease}.preview-modal-content__media-container iframe:hover{box-shadow:0 4px 16px rgba(var(--center-channel-color-rgb), 0.12);transform:translateY(-1px)}.custom-video-wrapper{position:relative;width:100%;height:100%;cursor:pointer}.custom-video-wrapper video{display:block;width:100%;height:100%;background:#000;object-fit:contain}.custom-play-button{position:absolute;z-index:2;top:50%;left:50%;border:none;background:none;cursor:pointer;transform:translate(-50%, -50%);transition:transform .2s ease,opacity .2s ease}.custom-play-button:hover{transform:translate(-50%, -50%) scale(1.1)}.custom-play-button:active{transform:translate(-50%, -50%) scale(0.95)}.custom-play-button svg{filter:drop-shadow(0 2px 8px rgba(0, 0, 0, 0.3))}.custom-play-button circle{transition:fill .2s ease}.custom-play-button:hover circle{fill:#fff}
.preview-modal-controller.modal-dialog{width:640px;height:614px}.preview-modal-controller.modal-dialog.GenericModal{margin-top:calc(50vh - 307px)}.preview-modal-controller__footer{display:flex;width:100%;align-items:center;justify-content:space-between}.preview-modal-controller__pagination{display:flex;align-items:center;gap:12px}.preview-modal-controller__pagination-dots{display:flex;gap:8px}.preview-modal-controller__dot{width:8px;height:8px;border-radius:50%;background:rgba(var(--center-channel-color-rgb), 0.16);transition:background .2s ease}.preview-modal-controller__dot--active{background:var(--button-bg)}.preview-modal-controller__page-counter{color:rgb(var(--center-channel-color-rgb));font-size:12px;font-weight:400}.preview-modal-controller__navigation-buttons{display:flex}.preview-modal-controller .modal-content .modal-header{min-height:0}.preview-modal-controller .modal-body .GenericModal__body.padding{padding:8px 48px !important}

/*# sourceMappingURL=3891.9e862d6edf0a13408886.css.map*/