.clInput{display:block;margin-bottom:20px}.clWrapper{width:auto;padding:25px}.clCenterBackground{background-color:var(--center-channel-bg)}.clSidebarBackground{background-color:var(--sidebar-bg)}

/*# sourceMappingURL=6549.88fa9f7d580d651ac371.css.map*/