"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[694],{694:(e,t,r)=>{r.r(t),r.d(t,{default:()=>c}),r(43617),r(81975),r(93991);var n=r(36418),a=r.n(n),l=r(37270),s=r(77440),o=r(7344),i=r(83040);const c=function(e){const{pluggableId:t,pluggableName:r,subComponentName:n="",...c}=e,u=(0,l.useSelector)(s.O4),p=(0,l.useSelector)((e=>{const t=e.plugins.components;if(Object.hasOwn(t,r))return t[r]}));if(!r||!p)return null;let d,m=[...p];return t&&(m=m.filter((e=>e.id===t))),d="Product"===r?m.map((e=>{if(!n||!e[n])return null;const t=e[n];return a().createElement(i.A,{key:r+e.id,pluginId:e.pluginId},a().createElement(t,Object.assign({},c,{theme:u})))})):m.map((e=>{if(!("component"in e)||!e.component)return null;const t=e.component;return a().createElement(i.A,{key:r+e.id,pluginId:e.pluginId},a().createElement(t,Object.assign({},c,{theme:u,webSocketClient:o.A})))})),a().createElement(a().Fragment,null,d)}},7344:(e,t,r)=>{r.d(t,{A:()=>n});const n=new(r(85622).WebSocketClient)},83040:(e,t,r)=>{r.d(t,{A:()=>i});var n=r(36418),a=r.n(n),l=r(14778),s=r(67166);const o=r.n(s)().div.withConfig({displayName:"WrapperDiv"})(["align-items:center;display:flex;flex-direction:column;height:100%;justify-content:center;width:100%;#root > &{grid-area:announcement;display:flex;word-break:normal;flex-direction:row;gap:10px;height:40px;}"]);class i extends a().PureComponent{state={hasError:!1};static getDerivedStateFromError(){return{hasError:!0}}clearErrorState=e=>{e.preventDefault(),e.stopPropagation(),this.setState({hasError:!1})};render(){return this.state.hasError?a().createElement(o,null,a().createElement(l.FormattedMessage,{id:"pluggable.errorOccurred",defaultMessage:"An error occurred in the {pluginId} plugin.",values:{pluginId:this.props.pluginId}}),a().createElement("br",null),a().createElement("a",{href:"#",onClick:this.clearErrorState},a().createElement(l.FormattedMessage,{id:"pluggable.errorRefresh",defaultMessage:"Refresh?"}))):this.props.children}}}}]);
//# sourceMappingURL=694.863d45155176457895ab.js.map