"use strict";(self.webpackChunkmattermost_webapp=self.webpackChunkmattermost_webapp||[]).push([[745],{30745:(e,a,t)=>{t.r(a),t.d(a,{default:()=>o});var n=t(71633),s=t.n(n),r=t(36418),c=t.n(r),l=t(14778),i=t(37270),m=t(81911),p=t(85406),d=t(14776),u=t(7430),b=t(45222);const o=()=>{const{url:e}=(0,m.useRouteMatch)(),{pathname:a}=(0,m.useLocation)(),t=(0,i.useSelector)(d.Sy),n=(0,i.useSelector)(u.WR),r=(0,b.A)("EnableAIRecaps"),o=null!=(0,m.matchPath)(a,{path:"/:team/recaps/:recapId?"});return t&&n&&"true"===r?c().createElement("ul",{className:"SidebarRecaps NavGroupContent nav nav-pills__container"},c().createElement("li",{id:"sidebar-recaps-button",className:s()("SidebarChannel",{active:o}),tabIndex:-1},c().createElement(m.Link,{to:`${e}/recaps`,id:"sidebarItem_recaps",draggable:"false",className:"SidebarLink sidebar-item",tabIndex:0},c().createElement("span",{className:"icon"},c().createElement(p.CreationOutlineIcon,{size:18})),c().createElement("div",{className:"SidebarChannelLinkLabel_wrapper"},c().createElement("span",{className:"SidebarChannelLinkLabel sidebar-item__name"},c().createElement(l.FormattedMessage,{id:"recaps.sidebarLink",defaultMessage:"Recaps"})))))):null}},45222:(e,a,t)=>{t.d(a,{A:()=>r});var n=t(37270),s=t(26614);function r(e){return(0,n.useSelector)((a=>(0,s.Y6)(a,e)))}}}]);
//# sourceMappingURL=745.2215a2d296743d8288f5.js.map